MSG_HASH(
      MSG_COMPILER,
      "Compilador"
      )
MSG_HASH(
      MSG_UNKNOWN_COMPILER,
      "Compilador desconhecido"
      )
MSG_HASH(
      MSG_DEVICE_DISCONNECTED_FROM_PORT,
      "Dispositivo desconectado da porta"
      )
MSG_HASH(
      MSG_UNKNOWN_NETPLAY_COMMAND_RECEIVED,
      "Comando Netplay desconhecido recebido"
      )
MSG_HASH(
      MSG_FILE_ALREADY_EXISTS_SAVING_TO_BACKUP_BUFFER,
      "Este arquivo já existe. Salvando no buffer de backup"
      )
MSG_HASH(
      MSG_GOT_CONNECTION_FROM,
      "Conexão recebida de: \"%s\""
      )
MSG_HASH(
      MSG_GOT_CONNECTION_FROM_NAME,
      "Conexão recebida de: \"%s (%s)\""
      )
MSG_HASH(
      MSG_PUBLIC_ADDRESS,
      "Endereço público"
      )
MSG_HASH(
      MSG_NO_ARGUMENTS_SUPPLIED_AND_NO_MENU_BUILTIN,
      "Nenhum argumento fornecido e nenhum menu interno, exibindo ajuda..."
      )
MSG_HASH(
      MSG_SETTING_DISK_IN_TRAY,
      "Definindo disco na bandeja"
      )
MSG_HASH(
      MSG_WAITING_FOR_CLIENT,
      "Aguardando pelo cliente..."
      )
MSG_HASH(
      MSG_NETPLAY_YOU_HAVE_LEFT_THE_GAME,
      "Você deixou o jogo"
      )
MSG_HASH(
      MSG_NETPLAY_YOU_HAVE_JOINED_AS_PLAYER_N,
      "Você se juntou como jogador %u"
      )
MSG_HASH(
      MSG_NETPLAY_YOU_HAVE_JOINED_WITH_INPUT_DEVICES_S,
      "Você se juntou aos dispositivos de entrada %.*s"
      )
MSG_HASH(
      MSG_NETPLAY_PLAYER_S_LEFT,
      "O jogador %.*s deixou o jogo"
      )
MSG_HASH(
      MSG_NETPLAY_S_HAS_JOINED_AS_PLAYER_N,
      "%.*s se juntou como jogador %u"
      )
MSG_HASH(
      MSG_NETPLAY_S_HAS_JOINED_WITH_INPUT_DEVICES_S,
      "%.*s juntou-se a dispositivos de entrada %.*s"
      )
MSG_HASH(
      MSG_NETPLAY_NOT_RETROARCH,
      "Uma tentativa de conexão com o netplay falhou porque o par não está executando o RetroArch ou está executando uma versão antiga do RetroArch."
      )
MSG_HASH(
      MSG_NETPLAY_OUT_OF_DATE,
      "O par netplay está executando uma versão antiga do RetroArch. Não pode conectar."
      )
MSG_HASH(
      MSG_NETPLAY_DIFFERENT_VERSIONS,
      "ATENÇÃO: Um par de Netplay está executando uma versão diferente do RetroArch. Se ocorrerem problemas, use a mesma versão."
      )
MSG_HASH(
      MSG_NETPLAY_DIFFERENT_CORES,
      "Um par de netplay está executando um núcleo diferente. Não pode conectar."
      )
MSG_HASH(
      MSG_NETPLAY_DIFFERENT_CORE_VERSIONS,
      "ATENÇÃO: Um par de Netplay está executando uma versão diferente do núcleo. Se ocorrerem problemas, use a mesma versão."
      )
MSG_HASH(
      MSG_NETPLAY_ENDIAN_DEPENDENT,
      "Este núcleo não suporta Netplay inter-arquitetura entre estes sistemas"
      )
MSG_HASH(
      MSG_NETPLAY_PLATFORM_DEPENDENT,
      "Este núcleo não suporta Netplay inter-arquitetura"
      )
MSG_HASH(
      MSG_NETPLAY_ENTER_PASSWORD,
      "Digite a senha do servidor de Netplay:"
      )
MSG_HASH(
      MSG_NETPLAY_INCORRECT_PASSWORD,
      "Senha incorreta"
      )
MSG_HASH(
      MSG_NETPLAY_SERVER_NAMED_HANGUP,
      "\"%s\" desconectou"
      )
MSG_HASH(
      MSG_NETPLAY_SERVER_HANGUP,
      "Um cliente do Netplay desconectou"
      )
MSG_HASH(
      MSG_NETPLAY_CLIENT_HANGUP,
      "Desconectado do Netplay"
      )
MSG_HASH(
      MSG_NETPLAY_CANNOT_PLAY_UNPRIVILEGED,
      "Você não tem permissão para jogar"
      )
MSG_HASH(
      MSG_NETPLAY_CANNOT_PLAY_NO_SLOTS,
      "Não há vagas livres para jogadores"
      )
MSG_HASH(
      MSG_NETPLAY_CANNOT_PLAY_NOT_AVAILABLE,
      "Os dispositivos de entrada solicitados não estão disponíveis"
      )
MSG_HASH(
      MSG_NETPLAY_CANNOT_PLAY,
      "Impossível alterar para modo jogador"
      )
MSG_HASH(
      MSG_NETPLAY_PEER_PAUSED,
      "Par do Netplay \"%s\" pausou"
      )
MSG_HASH(
      MSG_NETPLAY_CHANGED_NICK,
      "Seu apelido mudou para \"%s\""
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_SHARED_CONTEXT,
      "Dar aos núcleos renderizados por hardware seu próprio contexto privado. Evita ter que assumir mudanças de estado de hardware entre quadros."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_MENU_SETTINGS,
      "Ajusta as configurações de aparência da tela de menu."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_HARD_SYNC,
      "Sincronia rígida entre CPU e GPU. Reduz a latência ao custo de desempenho."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_THREADED,
      "Melhora o desempenho ao custo de latência e mais engasgamento de vídeo. Use somente se você não puder obter velocidade total de outra forma."
      )
MSG_HASH(
      MSG_AUDIO_VOLUME,
      "Volume de áudio"
      )
MSG_HASH(
      MSG_AUTODETECT,
      "Detectar automaticamente"
      )
MSG_HASH(
      MSG_AUTOLOADING_SAVESTATE_FROM,
      "Autocarregando Estado de Jogo de"
      )
MSG_HASH(
      MSG_CAPABILITIES,
      "Capacidades"
      )
MSG_HASH(
      MSG_CONNECTING_TO_NETPLAY_HOST,
      "Conectando ao hospedeiro de Netplay"
      )
MSG_HASH(
      MSG_CONNECTING_TO_PORT,
      "Conectando a porta"
      )
MSG_HASH(
      MSG_CONNECTION_SLOT,
      "Vaga de conexão"
      )
MSG_HASH(
      MSG_SORRY_UNIMPLEMENTED_CORES_DONT_DEMAND_CONTENT_NETPLAY,
      "Desculpe, não implementado: núcleos que não exigem conteúdo não podem participar do Netplay."
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ACCOUNTS_CHEEVOS_PASSWORD,
      "Senha"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ACCOUNTS_CHEEVOS_SETTINGS,
      "Contas Cheevos"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ACCOUNTS_CHEEVOS_USERNAME,
      "Nome de usuário"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ACCOUNTS_LIST,
      "Contas"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ACCOUNTS_LIST_END,
      "Ponto Final da Lista de Contas"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ACCOUNTS_RETRO_ACHIEVEMENTS,
      "Retro Achievements"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ACHIEVEMENT_LIST,
      "Lista de Conquistas"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ACHIEVEMENT_LIST_HARDCORE,
      "Lista de Conquistas (Hardcore)"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ADD_CONTENT_LIST,
      "Analisar Conteúdo"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CONFIGURATIONS_LIST,
      "Configurações"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ADD_TAB,
      "Importar conteúdo"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_NETPLAY_TAB,
      "Salas de Netplay"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ASK_ARCHIVE,
      "Perguntar"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ASSETS_DIRECTORY,
      "Recursos"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_BLOCK_FRAMES,
      "Bloquear Quadros"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_DEVICE,
      "Dispositivo de Áudio"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_DRIVER,
      "Driver de Áudio"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_DSP_PLUGIN,
      "Plugin DSP de Áudio"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_ENABLE,
      "Habilitar Áudio"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_FILTER_DIR,
      "Filtro de Áudio"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_TURBO_DEADZONE_LIST,
      "Turbo/Zona-Morta"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_LATENCY,
      "Latência de Áudio (ms)"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_MAX_TIMING_SKEW,
      "Desvio Máximo de Tempo do Áudio"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_MUTE,
      "Áudio Mudo"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_OUTPUT_RATE,
      "Taxa da Saída de Áudio (Hz)"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_RATE_CONTROL_DELTA,
      "Controle Dinâmico da Taxa de Áudio"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_RESAMPLER_DRIVER,
      "Driver de Reamostragem de Áudio"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_SETTINGS,
      "Áudio"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_SYNC,
      "Sincronizar Áudio"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_VOLUME,
      "Nível de Volume de Áudio (dB)"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_WASAPI_EXCLUSIVE_MODE,
      "WASAPI Modo Exclusivo"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_WASAPI_FLOAT_FORMAT,
      "WASAPI Formato de Ponto Flutuante"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_WASAPI_SH_BUFFER_LENGTH,
      "WASAPI Tamanho do Buffer Compartilhado"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUTOSAVE_INTERVAL,
      "Intervalo do Salvamento Automático da SRAM"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUTO_OVERRIDES_ENABLE,
      "Carraga Automaticamente Arquivos de Redefinição"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUTO_REMAPS_ENABLE,
      "Carraga Automaticamente Arquivos de Remapeamento"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUTO_SHADERS_ENABLE,
      "Carraga Automaticamente Predefinições de Shader"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_CONTROLS_BACK,
      "Voltar"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_CONTROLS_CONFIRM,
      "Confirmar"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_CONTROLS_INFO,
      "Informações"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_CONTROLS_QUIT,
      "Sair"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_CONTROLS_SCROLL_DOWN,
      "Rolar para Baixo"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_CONTROLS_SCROLL_UP,
      "Rolar para Cima"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_CONTROLS_START,
      "Iniciar"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_CONTROLS_TOGGLE_KEYBOARD,
      "Alternar Teclado"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_CONTROLS_TOGGLE_MENU,
      "Alternar Menu"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_ENUM_CONTROLS,
      "Controles Básicos de Menu"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_ENUM_CONTROLS_CONFIRM,
      "Confirmar/OK"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_ENUM_CONTROLS_INFO,
      "Informação"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_ENUM_CONTROLS_QUIT,
      "Sair"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_ENUM_CONTROLS_SCROLL_UP,
      "Rolar para Cima"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_ENUM_CONTROLS_START,
      "Padrões"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_ENUM_CONTROLS_TOGGLE_KEYBOARD,
      "Alternar Teclado"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_ENUM_CONTROLS_TOGGLE_MENU,
      "Alternar Menu"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BLOCK_SRAM_OVERWRITE,
      "Não sobregravar a SRAM ao carregar Estado de Jogo"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BLUETOOTH_ENABLE,
      "Habilitar Bluetooth"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BUILDBOT_ASSETS_URL,
      "URL de Recursos do Buildbot"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CACHE_DIRECTORY,
      "Cache"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CAMERA_ALLOW,
      "Permitir Câmera"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CAMERA_DRIVER,
      "Driver de Câmera"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEAT,
      "Trapaça"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEAT_APPLY_CHANGES,
      "Aplicar Alterações"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEAT_DATABASE_PATH,
      "Arquivo de Trapaça"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEAT_FILE,
      "Arquivo de Trapaça"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEAT_FILE_LOAD,
      "Carregar Arquivo de Trapaça"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEAT_FILE_SAVE_AS,
      "Salvar Arquivo de Trapaça Como"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEAT_NUM_PASSES,
      "Estágios de Trapaça"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEEVOS_DESCRIPTION,
      "Descrição"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEEVOS_HARDCORE_MODE_ENABLE,
      "Conquistas no Modo Hardcore"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEEVOS_LEADERBOARDS_ENABLE,
      "Tabelas de Classificação"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEEVOS_BADGES_ENABLE,
      "Insígnias de Conquistas"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEEVOS_LOCKED_ACHIEVEMENTS,
      "Conquistas Bloqueadas:"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEEVOS_LOCKED_ENTRY,
      "Bloqueada"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEEVOS_SETTINGS,
      "Retro Achievements"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEEVOS_TEST_UNOFFICIAL,
      "Testar Conquistas Não Oficiais"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEEVOS_UNLOCKED_ACHIEVEMENTS,
      "Conquistas Desbloqueadas:"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEEVOS_UNLOCKED_ENTRY,
      "Desbloqueada"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEEVOS_UNLOCKED_ENTRY_HARDCORE,
      "Hardcore"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEEVOS_VERBOSE_ENABLE,
      "Modo Detalhado das Conquistas"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEEVOS_AUTO_SCREENSHOT,
      "Captura de Conquistas Automática"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CLOSE_CONTENT,
      "Fechar Conteúdo"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CONFIG,
      "Configuração"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CONFIGURATIONS,
      "Carregar Configuração"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CONFIGURATION_SETTINGS,
      "Configuração"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CONFIG_SAVE_ON_EXIT,
      "Salvar Configuração ao Sair"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CONTENT_COLLECTION_LIST,
      "Coleções"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CONTENT_DATABASE_DIRECTORY,
      "Base de Dados"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CONTENT_DIR,
      "Conteúdo"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CONTENT_HISTORY_SIZE,
      "Tamanho da Lista de Histórico")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PLAYLIST_ENTRY_REMOVE,
      "Permitir a remoção de itens")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SETTINGS,
      "Menu Rápido")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_ASSETS_DIR,
      "Recursos de Núcleo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_ASSETS_DIRECTORY,
      "Downloads")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_CHEAT_OPTIONS,
      "Trapaças")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_COUNTERS,
      "Contadores do Núcleo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_ENABLE,
      "Exibir nome do núcleo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INFORMATION,
      "Informação do Núcleo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INFO_AUTHORS,
      "Autores")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INFO_CATEGORIES,
      "Categorias")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INFO_CORE_LABEL,
      "Rótulo do núcleo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INFO_CORE_NAME,
      "Nome do núcleo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INFO_FIRMWARE,
      "Firmware(s)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INFO_LICENSES,
      "Licença(s)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INFO_PERMISSIONS,
      "Permissões")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INFO_SUPPORTED_EXTENSIONS,
      "Extensões suportadas")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INFO_SYSTEM_MANUFACTURER,
      "Fabricante do sistema")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INFO_SYSTEM_NAME,
      "Nome do sistema")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INPUT_REMAPPING_OPTIONS,
      "Controles")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_LIST,
      "Carregar Núcleo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_OPTIONS,
      "Opções")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_SETTINGS,
      "Núcleo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_SET_SUPPORTS_NO_CONTENT_ENABLE,
      "Iniciar um Núcleo Automaticamente")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_UPDATER_AUTO_EXTRACT_ARCHIVE,
      "Extrair automaticamente o arquivo baixado")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_UPDATER_BUILDBOT_URL,
      "URL de Núcleos do Buildbot")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_UPDATER_LIST,
      "Atualizador de Núcleo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_UPDATER_SETTINGS,
      "Atualizador")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CPU_ARCHITECTURE,
      "Arquitetura da CPU:")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CPU_CORES,
      "Cores da CPU:")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CURSOR_DIRECTORY,
      "Cursor")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CURSOR_MANAGER,
      "Gerenciar Cursor")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CUSTOM_RATIO,
      "Proporção Personalizada")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_MANAGER,
      "Gerenciar Base de Dados")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_SELECTION,
      "Seleção de Base de Dados")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DELETE_ENTRY,
      "Remover")
MSG_HASH(MENU_ENUM_LABEL_VALUE_FAVORITES,
      "Diretório Inicial")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DIRECTORY_CONTENT,
      "<Diretório de Conteúdo>")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DIRECTORY_DEFAULT,
      "<Padrão>")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DIRECTORY_NONE,
      "<Nenhum>")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DIRECTORY_NOT_FOUND,
      "Diretório não encontrado.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DIRECTORY_SETTINGS,
      "Diretório")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DISK_CYCLE_TRAY_STATUS,
      "Condição da Bandeja do Ciclo de Disco")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DISK_IMAGE_APPEND,
      "Anexar Imagem de Disco")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DISK_INDEX,
      "Índice de Disco")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DISK_OPTIONS,
      "Controle de Disco")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DONT_CARE,
      "Não importa")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DOWNLOADED_FILE_DETECT_CORE_LIST,
      "Downloads")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DOWNLOAD_CORE,
      "Baixar Núcleo...")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DOWNLOAD_CORE_CONTENT,
      "Download de Conteúdo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DPI_OVERRIDE_ENABLE,
      "Habilitar Redefinição de DPI")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DPI_OVERRIDE_VALUE,
      "Redefinição de DPI")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DRIVER_SETTINGS,
      "Driver")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DUMMY_ON_CORE_SHUTDOWN,
      "Carregar Modelo no Desligamento do Núcleo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CHECK_FOR_MISSING_FIRMWARE,
      "Verificar por Firmware que Falta Antes de Carregar")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DYNAMIC_WALLPAPER,
      "Plano de Fundo Dinâmico")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DYNAMIC_WALLPAPERS_DIRECTORY,
      "Planos de Fundo Dinâmicos")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CHEEVOS_ENABLE,
      "Habilitar Conquistas")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ENTRY_HOVER_COLOR,
      "Cor do item de menu ao passar o cursor")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ENTRY_NORMAL_COLOR,
      "Cor normal do item de menu")
MSG_HASH(MENU_ENUM_LABEL_VALUE_FALSE,
      "Falso")
MSG_HASH(MENU_ENUM_LABEL_VALUE_FASTFORWARD_RATIO,
      "Velocidade Máxima de Execução")
MSG_HASH(MENU_ENUM_LABEL_VALUE_FAVORITES_TAB,
      "Favoritos")
MSG_HASH(MENU_ENUM_LABEL_VALUE_FPS_SHOW,
      "Mostrar Taxa de Quadros")
MSG_HASH(MENU_ENUM_LABEL_VALUE_FRAME_THROTTLE_ENABLE,
      "Controlar Velocidade Máxima de Execução")
MSG_HASH(MENU_ENUM_LABEL_VALUE_FRAME_THROTTLE_SETTINGS,
      "Controle de Quadros")
MSG_HASH(MENU_ENUM_LABEL_VALUE_FRONTEND_COUNTERS,
      "Contadores do Frontend")
MSG_HASH(MENU_ENUM_LABEL_VALUE_GAME_SPECIFIC_OPTIONS,
      "Carraga Automaticamente Opções de Núcleo Específicas do Conteúdo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_GAME_SPECIFIC_OPTIONS_CREATE,
      "Criar arquivo de opções do jogo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_GAME_SPECIFIC_OPTIONS_IN_USE,
      "Arquivo de opções do jogo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_HELP,
      "Ajuda")
MSG_HASH(MENU_ENUM_LABEL_VALUE_HELP_AUDIO_VIDEO_TROUBLESHOOTING,
      "Solução de Problemas de Áudio/Vídeo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_HELP_CHANGE_VIRTUAL_GAMEPAD,
      "Alterando a Transparência de Gamepad Virtual")
MSG_HASH(MENU_ENUM_LABEL_VALUE_HELP_CONTROLS,
      "Controles Básicos de Menu")
MSG_HASH(MENU_ENUM_LABEL_VALUE_HELP_LIST,
      "Ajuda")
MSG_HASH(MENU_ENUM_LABEL_VALUE_HELP_LOADING_CONTENT,
      "Carregando Conteúdo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_HELP_SCANNING_CONTENT,
      "Procurando em Busca de Conteúdo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_HELP_WHAT_IS_A_CORE,
      "O Que É Um Núcleo?")
MSG_HASH(MENU_ENUM_LABEL_VALUE_HISTORY_LIST_ENABLE,
      "Habilitar Lista de Histórico")
MSG_HASH(MENU_ENUM_LABEL_VALUE_HISTORY_TAB,
      "Histórico")
MSG_HASH(MENU_ENUM_LABEL_VALUE_HORIZONTAL_MENU,
      "Menu Horizontal")
MSG_HASH(MENU_ENUM_LABEL_VALUE_IMAGES_TAB,
      "Imagem")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INFORMATION,
      "Informação")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INFORMATION_LIST,
      "Informação")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ADC_TYPE,
      "Tipo de Analógico Para Digital")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ALL_USERS_CONTROL_MENU,
      "Todos os Usuários Controlam o Menu")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_LEFT_X,
      "Analógico Esquerdo X")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_LEFT_X_MINUS,
      "Analógico Esquerdo X- (esquerda)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_LEFT_X_PLUS,
      "Analógico Esquerdo X+ (direita)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_LEFT_Y,
      "Analógico Esquerdo Y")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_LEFT_Y_MINUS,
      "Analógico Esquerdo Y- (cima)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_LEFT_Y_PLUS,
      "Analógico Esquerdo Y+ (baixo)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_RIGHT_X,
      "Analógico Direito X")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_RIGHT_X_MINUS,
      "Analógico Direito X- (esquerda)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_RIGHT_X_PLUS,
      "Analógico Direito X+ (direita)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_RIGHT_Y,
      "Analógico Direito Y")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_RIGHT_Y_MINUS,
      "Analógico Direito Y- (cima)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_RIGHT_Y_PLUS,
      "Analógico Direito Y+ (baixo)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_TRIGGER,
      "Gatinho da Pistola")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_RELOAD,
      "Recarregar Pistola")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_AUX_A,
      "Aux A da Pistola")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_AUX_B,
      "Aux B da Pistola")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_AUX_C,
      "Aux C da Pistola")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_START,
      "Start da Pistola")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_SELECT,
      "Select da Pistola")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_DPAD_UP,
      "D-pad Cima da Pistola")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_DPAD_DOWN,
      "D-pad Baixo da Pistola")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_DPAD_LEFT,
      "D-pad Esquerdo da Pistola")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_DPAD_RIGHT,
      "D-pad Direito da Pistola")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_AUTODETECT_ENABLE,
      "Habilitar Autoconfiguração")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_AXIS_THRESHOLD,
      "Zona Morta do Controle Analógico")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_INPUT_SWAP_OK_CANCEL,
      "Inverter Botões OK e Cancelar do Menu")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_BIND_ALL,
      "Vincular Todos")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_BIND_DEFAULT_ALL,
      "Vincular Todos pelo Padrão")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_BIND_TIMEOUT,
      "Tempo Limite para Vincular")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_DESCRIPTOR_HIDE_UNBOUND,
      "Ocultar Descritores de Entrada do Núcleo Não Vinculados")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_DESCRIPTOR_LABEL_SHOW,
      "Exibir Rótulos do Descritor de Entrada")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_DEVICE_INDEX,
      "Índice de Dispositivo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_DEVICE_TYPE,
      "Tipo de Dispositivo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MOUSE_INDEX,
      "Índice de Mouse")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_DRIVER,
      "Driver de Entrada")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_DUTY_CYCLE,
      "Ciclo de Trabalho")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_HOTKEY_BINDS,
      "Vínculos das Teclas de Atalho da Entrada")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ICADE_ENABLE,
      "Habilitar Mapeamento de Gamepad no Teclado")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_A,
      "Botão A (direita)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_B,
      "Botão B (baixo)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_DOWN,
      "Direcional para baixo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_L2,
      "Botão L2 (gatilho)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_L3,
      "Botão L3 (polegar)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_L,
      "Botão L (ombro)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_LEFT,
      "Direcional Esquerdo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_R2,
      "Botão R2 (gatilho)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_R3,
      "Botão R3 (polegar)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_R,
      "Botão R (ombro)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_RIGHT,
      "Direcional Direito")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_SELECT,
      "Botão Select")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_START,
      "Botão Start")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_UP,
      "Direcional para Cima")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_X,
      "Botão X (topo)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_Y,
      "Botão Y (esquerda)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_KEY,
      "(Tecla: %s)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MOUSE_LEFT,
      "Mouse 1")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MOUSE_RIGHT,
      "Mouse 2")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MOUSE_MIDDLE,
      "Mouse 3")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MOUSE_BUTTON4,
      "Mouse 4")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MOUSE_BUTTON5,
      "Mouse 5")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MOUSE_WHEEL_UP,
      "Roda do Mouse para Cima")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MOUSE_WHEEL_DOWN,
      "Roda do Mouse para Baixo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MOUSE_HORIZ_WHEEL_UP,
      "Roda do Mouse para Esquerda")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MOUSE_HORIZ_WHEEL_DOWN,
      "Roda do Mouse para Diretira")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_KEYBOARD_GAMEPAD_MAPPING_TYPE,
      "Tipo de Mapeamento para Gamepad no Teclado")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MAX_USERS,
      "Usuários Máximos")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MENU_ENUM_TOGGLE_GAMEPAD_COMBO,
      "Combinação do Gamepad para Alternar Menu")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_CHEAT_INDEX_MINUS,
      "Índice de Trapaça -")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_CHEAT_INDEX_PLUS,
      "Índice de Trapaça +")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_CHEAT_TOGGLE,
      "Alternar Trapaça")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_DISK_EJECT_TOGGLE,
      "Alternar ejeção de disco")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_DISK_NEXT,
      "Próximo disco")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_DISK_PREV,
      "Disco anterior")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_ENABLE_HOTKEY,
      "Habilitar teclas de atalho")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_FAST_FORWARD_HOLD_KEY,
      "Manter Avanço Rápido")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_FAST_FORWARD_KEY,
      "Alternar Avanço Rápido")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_FRAMEADVANCE,
      "Avanço de Quadro")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_FULLSCREEN_TOGGLE_KEY,
      "Alternar tela cheia")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_GRAB_MOUSE_TOGGLE,
      "Alternar captura do Mouse")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_GAME_FOCUS_TOGGLE,
      "Alternar foco do jogo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_UI_COMPANION_TOGGLE,
      "Alternar menu desktop")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_LOAD_STATE_KEY,
      "Carregar Estado de Jogo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_MENU_TOGGLE,
      "Alternar menu")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_MOVIE_RECORD_TOGGLE,
      "Alternar gravação de filme")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_MUTE,
      "Alternar áudio mudo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_NETPLAY_GAME_WATCH,
      "Alternar modo jogador/espectador do Netplay")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_OSK,
      "Alternar teclado virtual")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_OVERLAY_NEXT,
      "Próxima Transparência")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_PAUSE_TOGGLE,
      "Alternar pausa")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_QUIT_KEY,
      "Sair do RetroArch")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_RESET,
      "Reiniciar jogo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_REWIND,
      "Rebobinar")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_SAVE_STATE_KEY,
      "Salvar Estado de Jogo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_SCREENSHOT,
      "Capturar tela")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_SHADER_NEXT,
      "Próximo Shader")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_SHADER_PREV,
      "Shader Anterior")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_SLOWMOTION_HOLD_KEY,
      "Câmera Lenta")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_SLOWMOTION_KEY,
      "Alternar câmera lenta")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_STATE_SLOT_MINUS,
      "Compartimento do Estado de Jogo -")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_STATE_SLOT_PLUS,
      "Compartimento do Estado de Jogo +")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_VOLUME_DOWN,
      "Volume -")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_VOLUME_UP,
      "Volume +")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_OVERLAY_ENABLE,
      "Mostrar Transparência")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_OVERLAY_HIDE_IN_MENU,
      "Ocultar Transparência no Menu")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_OVERLAY_SHOW_PHYSICAL_INPUTS,
      "Exibir Comandos Na Transparência")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_OVERLAY_SHOW_PHYSICAL_INPUTS_PORT,
      "Porta de Escuta do Exibir Comandos ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_POLL_TYPE_BEHAVIOR,
      "Tipo de Comportamento da Chamada Seletiva")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_POLL_TYPE_BEHAVIOR_EARLY,
      "Mais cedo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_POLL_TYPE_BEHAVIOR_LATE,
      "Mais tarde")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_POLL_TYPE_BEHAVIOR_NORMAL,
      "Normal")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_PREFER_FRONT_TOUCH,
      "Preferir Toque Frontal")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_REMAPPING_DIRECTORY,
      "Remapeamento de Entrada")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_REMAP_BINDS_ENABLE,
      "Habilitar Remapeamento de Vínculos")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_SAVE_AUTOCONFIG,
      "Salvar Autoconfiguração")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_SETTINGS,
      "Entrada")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_SMALL_KEYBOARD_ENABLE,
      "Habilitar Teclado Pequeno")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_TOUCH_ENABLE,
      "Habilitar Toque")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_TURBO_ENABLE,
      "Habilitar Turbo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_TURBO_PERIOD,
      "Período do Turbo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_USER_BINDS,
      "Vínculos de Entrada do Usuário %u")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LATENCY_SETTINGS,
      "Latência")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INTERNAL_STORAGE_STATUS,
      "Condição do armazenamento interno")
MSG_HASH(MENU_ENUM_LABEL_VALUE_JOYPAD_AUTOCONFIG_DIR,
      "Autoconfiguração de Entrada")
MSG_HASH(MENU_ENUM_LABEL_VALUE_JOYPAD_DRIVER,
      "Driver de Joypad")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LAKKA_SERVICES,
      "Serviços")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_CHINESE_SIMPLIFIED,
      "Chinês (Simplificado)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_CHINESE_TRADITIONAL,
      "Chinês (Tradicional)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_DUTCH,
      "Holandês")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_ENGLISH,
      "Inglês")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_ESPERANTO,
      "Esperanto")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_FRENCH,
      "Francês")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_GERMAN,
      "Alemão")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_ITALIAN,
      "Italiano")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_JAPANESE,
      "Japonês")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_KOREAN,
      "Coreano")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_POLISH,
      "Polonês")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_PORTUGUESE_BRAZIL,
      "Português (Brasil)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_PORTUGUESE_PORTUGAL,
      "Português (Portugal)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_RUSSIAN,
      "Russo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_SPANISH,
      "Espanhol")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_VIETNAMESE,
      "Vietnamita")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_ARABIC,
      "Árabe")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LEFT_ANALOG,
      "Analógico Esquerdo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LIBRETRO_DIR_PATH,
      "Núcleo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LIBRETRO_INFO_PATH,
      "Informação do Núcleo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LIBRETRO_LOG_LEVEL,
      "Nível de Registro de Eventos do Núcleo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LINEAR,
      "Linear")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LOAD_ARCHIVE,
      "Carregar Arquivo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LOAD_CONTENT_HISTORY,
      "Carregar Recente")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LOAD_CONTENT_LIST,
      "Carregar Conteúdo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LOAD_STATE,
      "Carregar Estado de Jogo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LOCATION_ALLOW,
      "Permitir Localização")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LOCATION_DRIVER,
      "Driver de Localização")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LOGGING_SETTINGS,
      "Registro de Eventos")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LOG_VERBOSITY,
      "Verbosidade do Registro de Eventos")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MAIN_MENU,
      "Menu Principal")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MANAGEMENT,
      "Configurações da Base de Dados")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MATERIALUI_MENU_COLOR_THEME,
      "Tema de Cor do Menu")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MATERIALUI_MENU_COLOR_THEME_BLUE,
      "Azul")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MATERIALUI_MENU_COLOR_THEME_BLUE_GREY,
      "Cinza Azulado")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MATERIALUI_MENU_COLOR_THEME_DARK_BLUE,
      "Azul Escuro")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MATERIALUI_MENU_COLOR_THEME_GREEN,
      "Verde")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MATERIALUI_MENU_COLOR_THEME_NVIDIA_SHIELD,
      "Shield")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MATERIALUI_MENU_COLOR_THEME_RED,
      "Vermelho")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MATERIALUI_MENU_COLOR_THEME_YELLOW,
      "Amarelo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MATERIALUI_MENU_FOOTER_OPACITY,
      "Opacidade do Rodapé")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MATERIALUI_MENU_HEADER_OPACITY,
      "Opacidade do Cabeçalho")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_DRIVER,
      "Driver de Menu")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_ENUM_THROTTLE_FRAMERATE,
      "Controlar Taxa de Quadros do Menu")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_FILE_BROWSER_SETTINGS,
      "Configurações")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_LINEAR_FILTER,
      "Filtro Linear de Menu")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_HORIZONTAL_ANIMATION,
      "Animação Horizontal")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_SETTINGS,
      "Aparência")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_WALLPAPER,
      "Plano de Fundo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_WALLPAPER_OPACITY,
      "Opacidade do plano de fundo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MISSING,
      "Faltando")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MORE,
      "...")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MOUSE_ENABLE,
      "Suporte para Mouse")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MULTIMEDIA_SETTINGS,
      "Multimídia")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MUSIC_TAB,
      "Música")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NAVIGATION_BROWSER_FILTER_SUPPORTED_EXTENSIONS_ENABLE,
      "Filtrar Extensões Desconhecidas")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NAVIGATION_WRAPAROUND,
      "Navegação Retorna ao Início")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NEAREST,
      "Mais Próximo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY,
      "Netplay")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_ALLOW_SLAVES,
      "Permitir Clientes em Modo Escravo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_CHECK_FRAMES,
      "Verificar Quadros do Netplay")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_INPUT_LATENCY_FRAMES_MIN,
      "Quadros de Latência de Entrada")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_INPUT_LATENCY_FRAMES_RANGE,
      "Faixa de Quadros de Latência de Entrada")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_DELAY_FRAMES,
      "Atraso de Quadros do Netplay")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_DISCONNECT,
      "Desconectar do hospedeiro de Netplay")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_ENABLE,
      "Habilitar Netplay")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_ENABLE_CLIENT,
      "Conectar ao hospedeiro de Netplay")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_ENABLE_HOST,
      "Iniciar hospedeiro de Netplay")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_DISABLE_HOST,
      "Parar hospedeiro de Netplay")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_IP_ADDRESS,
      "Endereço do Servidor")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_LAN_SCAN_SETTINGS,
      "Analisar a rede local")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_MODE,
      "Habilitar Cliente Netplay")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_NICKNAME,
      "Usuário")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_PASSWORD,
      "Senha do Servidor")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_PUBLIC_ANNOUNCE,
      "Anunciar Netplay Publicamente")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_REQUEST_DEVICE_I,
      "Solicitar Dispositivo %u")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_REQUIRE_SLAVES,
      "Não Permitir Clientes em Modo Não Escravo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_SETTINGS,
      "Configurações do Netplay")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_SHARE_ANALOG,
      "Compartilhamento de Entrada Analógica")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_SHARE_ANALOG_MAX,
      "Máximo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_SHARE_ANALOG_AVERAGE,
      "Médio")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_SHARE_DIGITAL,
      "Compartilhamento de Entrada Digital")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_SHARE_DIGITAL_OR,
      "Compartilhar")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_SHARE_DIGITAL_XOR,
      "Agarrar")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_SHARE_DIGITAL_VOTE,
      "Eleger")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_SHARE_NONE,
      "Nenhum")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_SHARE_NO_PREFERENCE,
      "Sem preferência")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_START_AS_SPECTATOR,
      "Modo Espectador do Netplay")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_STATELESS_MODE,
      "Modo sem Estados de Jogo do Netplay")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_SPECTATE_PASSWORD,
      "Senha Apenas Espectador do Servidor")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_SPECTATOR_MODE_ENABLE,
      "Habilitar Espectador do Netplay")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_TCP_UDP_PORT,
      "Porta TCP do Netplay")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_NAT_TRAVERSAL,
      "Travessia de NAT do Netplay")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETWORK_CMD_ENABLE,
      "Comandos de Rede")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETWORK_CMD_PORT,
      "Porta de Comando de Rede")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETWORK_INFORMATION,
      "Informação de Rede")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETWORK_REMOTE_ENABLE,
      "Gamepad de Rede")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETWORK_REMOTE_PORT,
      "Porta Base Remota de Rede")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETWORK_SETTINGS,
      "Rede")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO,
      "Não")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NONE,
      "Nenhum")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NOT_AVAILABLE,
      "N/D")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_ACHIEVEMENTS_TO_DISPLAY,
      "Não há Conquistas para mostrar.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_CORE,
      "Nenhum Núcleo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_CORES_AVAILABLE,
      "Nenhum núcleo disponível")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_CORE_INFORMATION_AVAILABLE,
      "Não há informação de núcleo disponível.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_CORE_OPTIONS_AVAILABLE,
      "Não há opções de núcleo disponíveis.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_ENTRIES_TO_DISPLAY,
      "Não há itens para mostrar.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_HISTORY_AVAILABLE,
      "Não há histórico disponível.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_INFORMATION_AVAILABLE,
      "Não há informação disponível.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_ITEMS,
      "Sem itens.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_NETPLAY_HOSTS_FOUND,
      "Nenhum hospedeiro de Netplay encontrado.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_NETWORKS_FOUND,
      "Nenhuma rede encontrada.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_PERFORMANCE_COUNTERS,
      "Não há contadores de desempenho.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_PLAYLISTS,
      "Não há listas de reprodução.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_PLAYLIST_ENTRIES_AVAILABLE,
      "Não há itens de lista de reprodução disponíveis.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_SETTINGS_FOUND,
      "Nenhuma configuração encontrada.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_SHADER_PARAMETERS,
      "Não há parâmetros de Shader.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_OFF,
      "DESLIGADO")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ON,
      "LIGADO")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ONLINE,
      "Online")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ONLINE_UPDATER,
      "Atualizador Online")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ONSCREEN_DISPLAY_SETTINGS,
      "Exibição na Tela")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ONSCREEN_OVERLAY_SETTINGS,
      "Transparência na Tela")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ONSCREEN_NOTIFICATIONS_SETTINGS,
      "Notificações na Tela")
MSG_HASH(MENU_ENUM_LABEL_VALUE_OPEN_ARCHIVE,
      "Navegar no Arquivo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_OPTIONAL,
      "Opcional")
MSG_HASH(MENU_ENUM_LABEL_VALUE_OVERLAY,
      "Transparência")
MSG_HASH(MENU_ENUM_LABEL_VALUE_OVERLAY_AUTOLOAD_PREFERRED,
      "Carraga Automaticamente Transparência Favorita")
MSG_HASH(MENU_ENUM_LABEL_VALUE_OVERLAY_DIRECTORY,
      "Transparência")
MSG_HASH(MENU_ENUM_LABEL_VALUE_OVERLAY_OPACITY,
      "Opacidade da Transparência")
MSG_HASH(MENU_ENUM_LABEL_VALUE_OVERLAY_PRESET,
      "Predefinição de Transparência")
MSG_HASH(MENU_ENUM_LABEL_VALUE_OVERLAY_SCALE,
      "Escala da Transparência")
MSG_HASH(MENU_ENUM_LABEL_VALUE_OVERLAY_SETTINGS,
      "Transparência na Tela")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PAL60_ENABLE,
      "Utilizar Modo PAL60")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PARENT_DIRECTORY,
      "Diretório superior")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PAUSE_LIBRETRO,
      "Pausar quando o menu for ativado")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PAUSE_NONACTIVE,
      "Não rodar em segundo plano")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PERFCNT_ENABLE,
      "Contadores de Desempenho")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PLAYLISTS_TAB,
      "Listas de Reprodução")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PLAYLIST_DIRECTORY,
      "Lista de Reprodução")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PLAYLIST_SETTINGS,
      "Listas de Reprodução")
MSG_HASH(MENU_ENUM_LABEL_VALUE_POINTER_ENABLE,
      "Suporte para Toque")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PORT,
      "Porta")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PRESENT,
      "Presente")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PRIVACY_SETTINGS,
      "Privacidade")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUIT_RETROARCH,
      "Sair do RetroArch")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_ANALOG,
      "Analógico suportado")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_BBFC_RATING,
      "Classificação BBFC")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_CERO_RATING,
      "Classificação CERO")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_COOP,
      "Cooperativo suportado")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_CRC32,
      "CRC32")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_DESCRIPTION,
      "Descrição")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_DEVELOPER,
      "Desenvolvedor")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_EDGE_MAGAZINE_ISSUE,
      "Edição da Revista Edge")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_EDGE_MAGAZINE_RATING,
      "Classificação da Revista Edge")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_EDGE_MAGAZINE_REVIEW,
      "Análise da Revista Edge")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_ELSPA_RATING,
      "Classificação ELSPA")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_ENHANCEMENT_HW,
      "Hardware de Aprimoramento")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_ESRB_RATING,
      "Classificação ESRB")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_FAMITSU_MAGAZINE_RATING,
      "Classificação da Revista Famitsu")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_FRANCHISE,
      "Franquia")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_GENRE,
      "Gênero")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_MD5,
      "MD5")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_NAME,
      "Nome")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_ORIGIN,
      "Origem")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_PEGI_RATING,
      "Classificação PEGI")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_PUBLISHER,
      "Editor")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_RELEASE_MONTH,
      "Mês de Lançamento")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_RELEASE_YEAR,
      "Ano de Lançamento")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_RUMBLE,
      "Suporte para Vibração")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_SERIAL,
      "Número de Série")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_SHA1,
      "SHA1")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_START_CONTENT,
      "Iniciar Conteúdo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_TGDB_RATING,
      "Classificação TGDB")
MSG_HASH(MENU_ENUM_LABEL_VALUE_REBOOT,
      "Reiniciar")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RECORDING_CONFIG_DIRECTORY,
      "Configuração de Gravação")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RECORDING_OUTPUT_DIRECTORY,
      "Saída de Gravação")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RECORDING_SETTINGS,
      "Gravação")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RECORD_CONFIG,
      "Carregar Configuração de Gravação...")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RECORD_DRIVER,
      "Driver de Gravação")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RECORD_ENABLE,
      "Habilitar Gravação")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RECORD_PATH,
      "Salvar Saída de Gravação Como...")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RECORD_USE_OUTPUT_DIRECTORY,
      "Salvar Gravações no Diretório de Saída")
MSG_HASH(MENU_ENUM_LABEL_VALUE_REMAP_FILE,
      "Arquivo de Remapeamento")
MSG_HASH(MENU_ENUM_LABEL_VALUE_REMAP_FILE_LOAD,
      "Carregar Arquivo de Remapeamento")
MSG_HASH(MENU_ENUM_LABEL_VALUE_REMAP_FILE_SAVE_CORE,
      "Salvar Arquivo de Remapeamento de Núcleo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_REMAP_FILE_SAVE_GAME,
      "Salvar Arquivo de Remapeamento de Jogo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_REMAP_FILE_REMOVE_CORE,
      "Remover Arquivo de Remapeamento de Núcleo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_REMAP_FILE_REMOVE_GAME,
      "Remover Arquivo de Remapeamento de Jogo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_REQUIRED,
      "Obrigatório")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RESTART_CONTENT,
      "Reiniciar")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RESTART_RETROARCH,
      "Reiniciar RetroArch")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RESUME,
      "Retomar")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RESUME_CONTENT,
      "Retomar")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RETROKEYBOARD,
      "RetroKeyboard")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RETROPAD,
      "RetroPad")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RETROPAD_WITH_ANALOG,
      "RetroPad com Analógico")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RETRO_ACHIEVEMENTS_SETTINGS,
      "Conquistas")
MSG_HASH(MENU_ENUM_LABEL_VALUE_REWIND_ENABLE,
      "Habilitar Rebobinagem")
MSG_HASH(MENU_ENUM_LABEL_VALUE_REWIND_GRANULARITY,
      "Granularidade da Rebobinagem")
MSG_HASH(MENU_ENUM_LABEL_VALUE_REWIND_SETTINGS,
      "Rebobinagem")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RGUI_BROWSER_DIRECTORY,
      "Navegador de Arquivos")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RGUI_CONFIG_DIRECTORY,
      "Configuração")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RGUI_SHOW_START_SCREEN,
      "Mostrar Tela Inicial")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RIGHT_ANALOG,
      "Analógico Direito")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ADD_TO_FAVORITES,
      "Adicionar aos Favoritos")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ADD_TO_FAVORITES_PLAYLIST,
      "Adicionar aos Favoritos")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RESET_CORE_ASSOCIATION,
      "Redefinir Associação do Núcleo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RUN,
      "Executar")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RUN_MUSIC,
      "Executar")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAMBA_ENABLE,
      "Habilitar SAMBA")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVEFILE_DIRECTORY,
      "Arquivo de Jogo-Salvo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVESTATE_AUTO_INDEX,
      "Índice Automático de Estado de Jogo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVESTATE_AUTO_LOAD,
      "Carraga Automaticamente Estado de Jogo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVESTATE_AUTO_SAVE,
      "Salvar Automaticamente Estado de Jogo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVESTATE_DIRECTORY,
      "Arquivo de Estado de Jogo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVESTATE_THUMBNAIL_ENABLE,
      "Miniaturas do Estado de Jogo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVE_CURRENT_CONFIG,
      "Salvar Configuração Atual")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVE_CURRENT_CONFIG_OVERRIDE_CORE,
      "Salvar Redefinição de Núcleo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVE_CURRENT_CONFIG_OVERRIDE_GAME,
      "Salvar Redefinição de Jogo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVE_NEW_CONFIG,
      "Salvar Nova Configuração")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVE_STATE,
      "Salvar Estado de Jogo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVING_SETTINGS,
      "Salvando")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SCAN_DIRECTORY,
      "Analisar Diretório")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SCAN_FILE,
      "Analisar Arquivo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SCAN_THIS_DIRECTORY,
      "<Analisar Este Diretório>")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SCREENSHOT_DIRECTORY,
      "Captura de Tela")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SCREEN_RESOLUTION,
      "Resolução da Tela")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SEARCH,
      "Procurar")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SECONDS,
      "segundos")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SETTINGS,
      "Configurações")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SETTINGS_TAB,
      "Configurações")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHADER,
      "Shader")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHADER_APPLY_CHANGES,
      "Aplicar Alterações")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHADER_OPTIONS,
      "Shaders")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHADER_PIPELINE_RIBBON,
      "Faixa")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHADER_PIPELINE_RIBBON_SIMPLIFIED,
      "Faixa (simplificada)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHADER_PIPELINE_SIMPLE_SNOW,
      "Neve Simples")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHADER_PIPELINE_SNOW,
      "Neve")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHOW_ADVANCED_SETTINGS,
      "Exibir Configurações Avançadas")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHOW_HIDDEN_FILES,
      "Exibir Arquivos e Pastas Ocultos")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHUTDOWN,
      "Desligar")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SLOWMOTION_RATIO,
      "Taxa de Câmera Lenta")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RUN_AHEAD_ENABLED,
      "Adiantar para Reduzir a Latência")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RUN_AHEAD_FRAMES,
      "Número de Quadros para Adiantar")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RUN_AHEAD_SECONDARY_INSTANCE,
      "Adiantar Usa uma Segunda Instância")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SORT_SAVEFILES_ENABLE,
      "Classificar Arquivos de Jogo-Salvo em Pastas")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SORT_SAVESTATES_ENABLE,
      "Classificar Arquivos de Estado de Jogo em Pastas")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVESTATES_IN_CONTENT_DIR_ENABLE,
      "Gravar Estados de Jogo no Diretório de Conteúdo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVEFILES_IN_CONTENT_DIR_ENABLE,
      "Gravar Jogos-Salvos no Diretório de Conteúdo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEMFILES_IN_CONTENT_DIR_ENABLE,
      "Arquivos de Sistema estão no Diretório de Conteúdo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SCREENSHOTS_IN_CONTENT_DIR_ENABLE,
      "Salvar Capturas de Tela no Diretório de Conteúdo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SSH_ENABLE,
      "Habilitar SSH")
MSG_HASH(MENU_ENUM_LABEL_VALUE_START_CORE,
      "Iniciar Núcleo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_START_NET_RETROPAD,
      "Iniciar RetroPad Remoto")
MSG_HASH(MENU_ENUM_LABEL_VALUE_START_VIDEO_PROCESSOR,
      "Iniciar Processador de Vídeo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_STATE_SLOT,
      "Compartimento do Estado de Jogo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_STATUS,
      "Condição")
MSG_HASH(MENU_ENUM_LABEL_VALUE_STDIN_CMD_ENABLE,
      "Comandos stdin")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SUPPORTED_CORES,
      "Núcleos Sugeridos")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SUSPEND_SCREENSAVER_ENABLE,
      "Desativar Protetor de Tela")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_BGM_ENABLE,
      "Habilitar Música em Segundo Plano do Sistema")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_DIRECTORY,
      "Sistema/BIOS")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFORMATION,
      "Informação do Sistema")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_7ZIP_SUPPORT,
      "Suporte a 7zip")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_ALSA_SUPPORT,
      "Suporte a ALSA")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_BUILD_DATE,
      "Data de Compilação")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_CG_SUPPORT,
      "Suporte a Cg")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_COCOA_SUPPORT,
      "Suporte a Cocoa")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_COMMAND_IFACE_SUPPORT,
      "Suporte à Interface de Comando")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_CORETEXT_SUPPORT,
      "Suporte a CoreText")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_CPU_FEATURES,
      "Características de CPU")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_DISPLAY_METRIC_DPI,
      "Métrica DPI da Tela")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_DISPLAY_METRIC_MM_HEIGHT,
      "Métrica de Altura da Tela (mm)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_DISPLAY_METRIC_MM_WIDTH,
      "Métrica de Largura da Tela (mm)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_DSOUND_SUPPORT,
      "Suporte a DirectSound")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_WASAPI_SUPPORT,
      "Suporte a WASAPI")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_DYLIB_SUPPORT,
      "Suporte à biblioteca dinâmica")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_DYNAMIC_SUPPORT,
      "Carregamento dinâmico em tempo de execução da biblioteca libretro")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_EGL_SUPPORT,
      "Suporte a EGL")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_FBO_SUPPORT,
      "Suporte a OpenGL/Direct3D render-to-texture (multi-pass shaders)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_FFMPEG_SUPPORT,
      "Suporte a FFmpeg")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_FREETYPE_SUPPORT,
      "Suporte a FreeType")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_FRONTEND_IDENTIFIER,
      "Identificador do Frontend")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_FRONTEND_NAME,
      "Nome do Frontend")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_FRONTEND_OS,
      "SO do Frontend")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_GIT_VERSION,
      "Versão Git")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_GLSL_SUPPORT,
      "Suporte a GLSL")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_HLSL_SUPPORT,
      "Suporte a HLSL")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_JACK_SUPPORT,
      "Suporte a JACK")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_KMS_SUPPORT,
      "Suporte a KMS/EGL")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_LAKKA_VERSION,
      "Versão Lakka")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_LIBRETRODB_SUPPORT,
      "Suporte a LibretroDB")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_LIBUSB_SUPPORT,
      "Suporte a Libusb")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_LIBXML2_SUPPORT,
      "Suporte a libxml2 XML parsing")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_NETPLAY_SUPPORT,
      "Suporte Netplay (ponto-a-ponto)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_NETWORK_COMMAND_IFACE_SUPPORT,
      "Suporte à Interface de comando de rede")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_NETWORK_REMOTE_SUPPORT,
      "Suporte a Gamepad de Rede")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_OPENAL_SUPPORT,
      "Suporte a OpenAL")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_OPENGLES_SUPPORT,
      "Suporte a OpenGL ES")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_OPENGL_SUPPORT,
      "Suporte a OpenGL")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_OPENSL_SUPPORT,
      "Suporte a OpenSL")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_OPENVG_SUPPORT,
      "Suporte a OpenVG")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_OSS_SUPPORT,
      "Suporte a OSS")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_OVERLAY_SUPPORT,
      "Suporte à Transparência")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_POWER_SOURCE,
      "Fonte de Energia")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_POWER_SOURCE_CHARGED,
      "Carregado")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_POWER_SOURCE_CHARGING,
      "Carregando")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_POWER_SOURCE_DISCHARGING,
      "Descarregando")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_POWER_SOURCE_NO_SOURCE,
      "Não há fonte")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_PULSEAUDIO_SUPPORT,
      "Suporte a PulseAudio")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_PYTHON_SUPPORT,
      "Suporte a Python (suporte de script em Shaders)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_RBMP_SUPPORT,
      "Suporte a BMP (RBMP)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_RETRORATING_LEVEL,
      "Nível RetroRating")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_RJPEG_SUPPORT,
      "Suporte a JPEG (RJPEG)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_ROARAUDIO_SUPPORT,
      "Suporte a RoarAudio")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_RPNG_SUPPORT,
      "Suporte a PNG (RPNG)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_RSOUND_SUPPORT,
      "Suporte a RSound")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_RTGA_SUPPORT,
      "Suporte a TGA (RTGA)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_SDL2_SUPPORT,
      "Suporte a SDL2")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_SDL_IMAGE_SUPPORT,
      "Suporte a imagem SDL")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_SDL_SUPPORT,
      "Suporte a SDL1.2")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_SLANG_SUPPORT,
      "Suporte a Slang")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_THREADING_SUPPORT,
      "Suporte a Paralelismo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_UDEV_SUPPORT,
      "Suporte a Udev")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_V4L2_SUPPORT,
      "Suporte a Video4Linux2")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_VIDEO_CONTEXT_DRIVER,
      "Driver de contexto de vídeo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_VULKAN_SUPPORT,
      "Suporte a Vulkan")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_WAYLAND_SUPPORT,
      "Suporte a Wayland")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_X11_SUPPORT,
      "Suporte a X11")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_XAUDIO2_SUPPORT,
      "Suporte a XAudio2")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_XVIDEO_SUPPORT,
      "Suporte a XVideo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_ZLIB_SUPPORT,
      "Suporte a Zlib")
MSG_HASH(MENU_ENUM_LABEL_VALUE_TAKE_SCREENSHOT,
      "Capturar tela")
MSG_HASH(MENU_ENUM_LABEL_VALUE_THREADED_DATA_RUNLOOP_ENABLE,
      "Paralelismo de tarefas")
MSG_HASH(MENU_ENUM_LABEL_VALUE_THUMBNAILS,
      "Miniaturas")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LEFT_THUMBNAILS,
      "Miniaturas à Esquerda")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_VERTICAL_THUMBNAILS,
      "Disposição Vertical de Miniaturas")
MSG_HASH(MENU_ENUM_LABEL_VALUE_THUMBNAILS_DIRECTORY,
      "Miniaturas")
MSG_HASH(MENU_ENUM_LABEL_VALUE_THUMBNAILS_UPDATER_LIST,
      "Atualizador de Miniaturas")
MSG_HASH(MENU_ENUM_LABEL_VALUE_THUMBNAIL_MODE_BOXARTS,
      "Arte da Embalagem")
MSG_HASH(MENU_ENUM_LABEL_VALUE_THUMBNAIL_MODE_SCREENSHOTS,
      "Captura de Tela")
MSG_HASH(MENU_ENUM_LABEL_VALUE_THUMBNAIL_MODE_TITLE_SCREENS,
      "Telas do Título")
MSG_HASH(MENU_ENUM_LABEL_VALUE_TIMEDATE_ENABLE,
      "Exibir data e hora")
MSG_HASH(MENU_ENUM_LABEL_VALUE_TITLE_COLOR,
      "Cor do título do menu")
MSG_HASH(MENU_ENUM_LABEL_VALUE_TRUE,
      "Verdadeiro")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UI_COMPANION_ENABLE,
      "Habilitar Companheiro da Interface de Usuário")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UI_COMPANION_START_ON_BOOT,
      "Companheiro da Interface de Usuário Roda na Inicialização")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UI_COMPANION_TOGGLE,
      "Mostrar menu desktop na inicialização")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DESKTOP_MENU_ENABLE,
      "Habilitar menu desktop (reiniciar)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UI_MENUBAR_ENABLE,
      "Barra de Menu")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UNABLE_TO_READ_COMPRESSED_FILE,
      "Incapaz de ler o arquivo comprimido.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UNDO_LOAD_STATE,
      "Desfazer Carregamento de Estado de Jogo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UNDO_SAVE_STATE,
      "Desfazer Salvamento de Estado de Jogo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UNKNOWN,
      "Desconhecido")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UPDATER_SETTINGS,
      "Atualizador")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UPDATE_ASSETS,
      "Atualizar Recursos")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UPDATE_AUTOCONFIG_PROFILES,
      "Atualizar Perfis de Autoconfiguração")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UPDATE_CG_SHADERS,
      "Atualizar Shaders Cg")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UPDATE_CHEATS,
      "Atualizar Trapaças")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UPDATE_CORE_INFO_FILES,
      "Atualizar Arquivos de Informação de Núcleo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UPDATE_DATABASES,
      "Atualizar Bases de Dados")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UPDATE_GLSL_SHADERS,
      "Atualizar Shaders GLSL")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UPDATE_LAKKA,
      "Atualizar Lakka")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UPDATE_OVERLAYS,
      "Atualizar Transparências")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UPDATE_SLANG_SHADERS,
      "Atualizar Shaders Slang")
MSG_HASH(MENU_ENUM_LABEL_VALUE_USER,
      "Usuário")
MSG_HASH(MENU_ENUM_LABEL_VALUE_KEYBOARD,
      "Kbd")
MSG_HASH(MENU_ENUM_LABEL_VALUE_USER_INTERFACE_SETTINGS,
      "Interface de Usuário")
MSG_HASH(MENU_ENUM_LABEL_VALUE_USER_LANGUAGE,
      "Idioma")
MSG_HASH(MENU_ENUM_LABEL_VALUE_USER_SETTINGS,
      "Usuário")
MSG_HASH(MENU_ENUM_LABEL_VALUE_USE_BUILTIN_IMAGE_VIEWER,
      "Utilizar o Visualizador de Imagem Integrado")
MSG_HASH(MENU_ENUM_LABEL_VALUE_USE_BUILTIN_PLAYER,
      "Utilizar o Reprodutor de Mídia Integrado")
MSG_HASH(MENU_ENUM_LABEL_VALUE_USE_THIS_DIRECTORY,
      "<Utilizar este diretório>")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_ALLOW_ROTATE,
      "Permitir rotação")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_ASPECT_RATIO,
      "Configurar Proporção de Tela")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_ASPECT_RATIO_AUTO,
      "Proporção de Tela Automática")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_ASPECT_RATIO_INDEX,
      "Proporção de Tela")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_BLACK_FRAME_INSERTION,
      "Inserção de Quadro Opaco")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_CROP_OVERSCAN,
      "Cortar Overscan (Recarregar)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_DISABLE_COMPOSITION,
      "Desativar Composição da Área de Trabalho")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_DRIVER,
      "Driver de Vídeo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_FILTER,
      "Filtro de Vídeo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_FILTER_DIR,
      "Filtro de Vídeo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_FILTER_FLICKER,
      "Filtro de tremulação de vídeo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_FONT_ENABLE,
      "Habilitar Notificações na Tela")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_FONT_PATH,
      "Fonte das Notificações na Tela")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_FONT_SIZE,
      "Tamanho da Notificação na Tela")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_FORCE_ASPECT,
      "Forçar Proporção de Tela")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_FORCE_SRGB_DISABLE,
      "Forçar Desativação de sRGB FBO")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_FRAME_DELAY,
      "Atraso de Quadro")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_FULLSCREEN,
      "Utilizar Modo de Tela Cheia")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_GAMMA,
      "Gama de Vídeo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_GPU_RECORD,
      "Usar Gravação da GPU")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_GPU_SCREENSHOT,
      "Habilitar Captura de Tela da GPU")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_HARD_SYNC,
      "Sincronia Rígida de GPU")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_HARD_SYNC_FRAMES,
      "Quadros de Sincronia Rígida de GPU")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_MAX_SWAPCHAIN_IMAGES,
      "Máximo de imagens na cadeia de troca")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_MESSAGE_POS_X,
      "Posição X da Notificação na Tela")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_MESSAGE_POS_Y,
      "Posição Y da Notificação na Tela")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_MONITOR_INDEX,
      "Índice de Monitor")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_POST_FILTER_RECORD,
      "Usar Gravação Pós-Filtro")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_REFRESH_RATE,
      "Taxa de Atualização Vertical")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_REFRESH_RATE_AUTO,
      "Taxa de Quadros Estimada da Tela")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_REFRESH_RATE_POLLED,
      "Definir Taxa de Atualização Reportada")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_ROTATION,
      "Rotação")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SCALE,
      "Escala em Janela")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SCALE_INTEGER,
      "Escala em Inteiros")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SETTINGS,
      "Vídeo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SHADER_DIR,
      "Shader de Vídeo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SHADER_NUM_PASSES,
      "Estágios de Shader")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SHADER_PARAMETERS,
      "Pré-visualizar Parâmetros de Shader")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SHADER_PRESET,
      "Carregar Predefinição de Shader")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SHADER_PRESET_SAVE_AS,
      "Salvar Predefinição de Shader Como")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SHADER_PRESET_SAVE_CORE,
      "Salvar Predefinição de Núcleo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SHADER_PRESET_SAVE_PARENT,
      "Salvar Predefinição de Diretório de Conteúdo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SHADER_PRESET_SAVE_GAME,
      "Salvar Predefinição de Jogo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SHARED_CONTEXT,
      "Habilitar Contexto Compartilhado de Hardware")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SMOOTH,
      "Filtragem Bilinear")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SOFT_FILTER,
      "Habilitar Filtro por Software")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SWAP_INTERVAL,
      "Intervalo de Troca da Sincronização Vertical (V-Sync)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_TAB,
      "Vídeo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_THREADED,
      "Vídeo Paralelizado")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_VFILTER,
      "Reduzir Tremulação de Vídeo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_VIEWPORT_CUSTOM_HEIGHT,
      "Altura Personalizada da Proporção de Tela")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_VIEWPORT_CUSTOM_WIDTH,
      "Largura Personalizada da Proporção de Tela")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_VIEWPORT_CUSTOM_X,
      "Posição X Personalizada da Proporção de Tela")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_VIEWPORT_CUSTOM_Y,
      "Posição Y Personalizada da Proporção de Tela")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_VI_WIDTH,
      "Definir Largura de Tela do VI")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_VSYNC,
      "Sincronização Vertical (V-Sync)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_WINDOWED_FULLSCREEN,
      "Modo Janela em Tela Cheia")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_WINDOW_WIDTH,
      "Largura da Janela")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_WINDOW_HEIGHT,
      "Altura da Janela")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_FULLSCREEN_X,
      "Largura em Tela Cheia")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_FULLSCREEN_Y,
      "Altura em Tela Cheia")
MSG_HASH(MENU_ENUM_LABEL_VALUE_WIFI_DRIVER,
      "Driver de Wi-Fi")
MSG_HASH(MENU_ENUM_LABEL_VALUE_WIFI_SETTINGS,
      "Wi-Fi")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_ALPHA_FACTOR,
      "Fator Alfa do Menu")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_FONT_COLOR_RED,
      "Cor Vermelha da Fonte do Menu")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_FONT_COLOR_GREEN,
      "Cor Verde da Fonte do Menu")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_FONT_COLOR_BLUE,
      "Cor Azul da Fonte do Menu")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_FONT,
      "Fonte do Menu")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_ICON_THEME_CUSTOM,
      "Personalizado")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_ICON_THEME_FLATUI,
      "FlatUI")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_ICON_THEME_MONOCHROME,
      "Monocromático")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_ICON_THEME_MONOCHROME_INVERTED,
       "Monocromático Invertido")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_ICON_THEME_SYSTEMATIC,
      "Sistemático")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_ICON_THEME_NEOACTIVE,
      "NeoActive")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_ICON_THEME_PIXEL,
      "Pixel")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_ICON_THEME_RETROACTIVE,
      "RetroActive")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_ICON_THEME_RETROSYSTEM,
      "Retrosystem")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_ICON_THEME_DOTART,
      "Dot-Art")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME,
      "Tema de Cor do Menu")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_APPLE_GREEN,
      "Verde Maçã")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_DARK,
      "Escuro")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_LIGHT,
      "Claro")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_MORNING_BLUE,
      "Azul da manhã")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_DARK_PURPLE,
      "Roxo Escuro")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_ELECTRIC_BLUE,
      "Azul Elétrico")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_GOLDEN,
      "Dourado")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_LEGACY_RED,
      "Vermelho Legado")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_MIDNIGHT_BLUE,
      "Azul Meia-noite")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_PLAIN,
      "Natural")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_UNDERSEA,
      "Submarino")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_VOLCANIC_RED,
      "Vermelho Vulcânico")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_RIBBON_ENABLE,
      "Pipeline do Shader de Menu")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_SCALE_FACTOR,
      "Fator de Escala do Menu")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_SHADOWS_ENABLE,
      "Habilitar Sombras dos Ícones")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_HISTORY,
      "Exibir Aba de Histórico")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_ADD,
      "Exibir Aba de Importação de Conteúdo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_PLAYLISTS,
      "Exibir Abas de Lista de Reprodução")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_FAVORITES,
      "Exibir Aba de Favoritos")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_IMAGES,
      "Exibir Aba de Imagem")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_MUSIC,
      "Exibir Aba de Música")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_SETTINGS,
      "Exibir Aba de Configurações")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_VIDEO,
      "Exibir Aba de Vídeo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_NETPLAY,
      "Exibir Aba de Netplay")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_LAYOUT,
      "Layout do Menu")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_THEME,
      "Tema de Ícones do Menu")
MSG_HASH(MENU_ENUM_LABEL_VALUE_YES,
      "Sim")
MSG_HASH(MENU_ENUM_LABEL_VIDEO_SHADER_PRESET_TWO,
      "Predefinição de Shader")
MSG_HASH(MENU_ENUM_SUBLABEL_CHEEVOS_ENABLE,
      "Habilitar ou desabilitar conquistas. Para mais informações, visite http://retroachievements.org")
MSG_HASH(MENU_ENUM_SUBLABEL_CHEEVOS_TEST_UNOFFICIAL,
      "Habilitar ou desabilitar conquistas não oficiais e/ou recursos beta para fins de teste.")
MSG_HASH(MENU_ENUM_SUBLABEL_CHEEVOS_HARDCORE_MODE_ENABLE,
      "Habilitar ou desabilitar Estado de Jogo, Trapaças, Rebobinagem, Avanço Rápido, Pausa e Câmera Lenta para todos os jogos.")
MSG_HASH(MENU_ENUM_SUBLABEL_CHEEVOS_LEADERBOARDS_ENABLE,
      "Habilitar ou desabilitar tabelas de classificação no jogo. Não tem efeito se o modo Hardcore estiver desativado.")
MSG_HASH(MENU_ENUM_SUBLABEL_CHEEVOS_BADGES_ENABLE,
      "Habilitar ou desabilitar a exibição de insígnia na Lista de Conquistas.")
MSG_HASH(MENU_ENUM_SUBLABEL_CHEEVOS_VERBOSE_ENABLE,
      "Habilitar ou desabilitar detalhes das conquistas na tela.")
MSG_HASH(MENU_ENUM_SUBLABEL_CHEEVOS_AUTO_SCREENSHOT,
      "Obter automaticamente uma captura de tela quando uma conquista é acionada.")
MSG_HASH(MENU_ENUM_SUBLABEL_DRIVER_SETTINGS,
      "Alterar os drivers utilizados pelo sistema.")
MSG_HASH(MENU_ENUM_SUBLABEL_RETRO_ACHIEVEMENTS_SETTINGS,
      "Alterar as configurações de conquistas.")
MSG_HASH(MENU_ENUM_SUBLABEL_CORE_SETTINGS,
      "Alterar as configurações de núcleo.")
MSG_HASH(MENU_ENUM_SUBLABEL_RECORDING_SETTINGS,
      "Alterar as configurações de gravação.")
MSG_HASH(MENU_ENUM_SUBLABEL_ONSCREEN_DISPLAY_SETTINGS,
      "Alterar as configurações de Transparência e Transparência de teclado, e as configurações de notificação na tela.")
MSG_HASH(MENU_ENUM_SUBLABEL_FRAME_THROTTLE_SETTINGS,
      "Alterar as configurações de Rebobinagem, Avanço Rápido e Câmera Lenta.")
MSG_HASH(MENU_ENUM_SUBLABEL_SAVING_SETTINGS,
      "Alterar as configurações de salvamento.")
MSG_HASH(MENU_ENUM_SUBLABEL_LOGGING_SETTINGS,
      "Alterar as configurações de registro de eventos.")
MSG_HASH(MENU_ENUM_SUBLABEL_USER_INTERFACE_SETTINGS,
      "Alterar as configurações da interface de usuário.")
MSG_HASH(MENU_ENUM_SUBLABEL_USER_SETTINGS,
      "Alterar as configurações de conta, nome de usuário e idioma.")
MSG_HASH(MENU_ENUM_SUBLABEL_PRIVACY_SETTINGS,
      "Alterar as configurações de privacidade.")
MSG_HASH(MENU_ENUM_SUBLABEL_DIRECTORY_SETTINGS,
      "Alterar os diretórios padrão onde os arquivos estão localizados.")
MSG_HASH(MENU_ENUM_SUBLABEL_PLAYLIST_SETTINGS,
      "Alterar as configurações de lista de reprodução.")
MSG_HASH(MENU_ENUM_SUBLABEL_NETWORK_SETTINGS,
      "Configurar as configurações de servidor e rede.")
MSG_HASH(MENU_ENUM_SUBLABEL_ADD_CONTENT_LIST,
      "Analisar conteúdo e adicionar na base de dados.")
MSG_HASH(MENU_ENUM_SUBLABEL_AUDIO_SETTINGS,
      "Alterar as configurações de saída de áudio.")
MSG_HASH(MENU_ENUM_SUBLABEL_BLUETOOTH_ENABLE,
      "Habilitar ou desabilitar o bluetooth.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONFIG_SAVE_ON_EXIT,
      "Salvar as alterações nos arquivos de configuração ao sair.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONFIGURATION_SETTINGS,
      "Alterar as definições padrão para os arquivos de configuração.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONFIGURATIONS_LIST,
      "Gerenciar e criar arquivos de configuração.")
MSG_HASH(MENU_ENUM_SUBLABEL_CPU_CORES,
      "Quantidade de Cores que a CPU possui.")
MSG_HASH(MENU_ENUM_SUBLABEL_FPS_SHOW,
      "Exibir a taxa atual de quadros por segundo na tela.")
MSG_HASH(MENU_ENUM_SUBLABEL_INPUT_HOTKEY_BINDS,
      "Ajustar configurações das teclas de atalho.")
MSG_HASH(MENU_ENUM_SUBLABEL_INPUT_MENU_ENUM_TOGGLE_GAMEPAD_COMBO,
      "Combinação de botões do Gamepad para alternar o menu.")
MSG_HASH(MENU_ENUM_SUBLABEL_INPUT_SETTINGS,
      "Alterar as configurações de Joypad, teclado e Mouse.")
MSG_HASH(MENU_ENUM_SUBLABEL_INPUT_USER_BINDS,
      "Configurar os controles para este usuário.")
MSG_HASH(MENU_ENUM_SUBLABEL_LATENCY_SETTINGS,
      "Altere as configurações relacionadas a vídeo, áudio e latência dos comandos.")
MSG_HASH(MENU_ENUM_SUBLABEL_LOG_VERBOSITY,
      "Habilitar ou desabilitar registro de eventos no terminal.")
MSG_HASH(MENU_ENUM_SUBLABEL_NETPLAY,
      "Juntar-se ou hospedar uma sessão de Netplay.")
MSG_HASH(MENU_ENUM_SUBLABEL_NETPLAY_LAN_SCAN_SETTINGS,
      "Procurar por e conectar aos hospedeiros de Netplay na rede local.")
MSG_HASH(MENU_ENUM_SUBLABEL_INFORMATION_LIST_LIST,
      "Exibir informações de núcleo, rede e sistema.")
MSG_HASH(MENU_ENUM_SUBLABEL_ONLINE_UPDATER,
      "Baixar complementos, componentes e conteúdo para o RetroArch.")
MSG_HASH(MENU_ENUM_SUBLABEL_SAMBA_ENABLE,
      "Habilitar ou desabilitar compartilhamento de pastas na rede.")
MSG_HASH(MENU_ENUM_SUBLABEL_SERVICES_SETTINGS,
      "Gerenciar serviços ao nível de sistema operacional.")
MSG_HASH(MENU_ENUM_SUBLABEL_SHOW_HIDDEN_FILES,
      "Exibir arquivos/diretórios ocultos no navegador de arquivos.")
MSG_HASH(MENU_ENUM_SUBLABEL_SSH_ENABLE,
      "Habilitar ou desabilitar acesso remoto à linha de comando.")
MSG_HASH(MENU_ENUM_SUBLABEL_SUSPEND_SCREENSAVER_ENABLE,
      "Prevenir que o protetor de tela do seu sistema seja ativado.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_WINDOW_SCALE,
      "Definir o tamanho da janela em relação ao tamanho da janela de exibição do núcleo. Como alternativa, você pode definir uma largura e altura de janela abaixo para um tamanho de janela fixo.")
MSG_HASH(MENU_ENUM_SUBLABEL_USER_LANGUAGE,
      "Definir o idioma da interface.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_BLACK_FRAME_INSERTION,
      "Inserir um quadro opaco entre quadros. Útil para usuários com telas de 120Hz que desejam jogar conteúdos em 60Hz para eliminar efeito de fantasma.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_FRAME_DELAY,
      "Reduz a latência ao custo de maior risco de engasgamento de vídeo. Adiciona um atraso após o V-Sync (em ms).")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_HARD_SYNC_FRAMES,
      "Definir quantos quadros a CPU pode rodar à frente da GPU quando utilizado o recurso 'Sincronia Rígida de GPU'.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_MAX_SWAPCHAIN_IMAGES,
      "Informar ao driver de vídeo para utilizar explicitamente um modo de buffer específico.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_MONITOR_INDEX,
      "Seleciona qual tela de exibição a ser usada.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_REFRESH_RATE_AUTO,
      "A taxa de atualização estimada da tela em Hz.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_REFRESH_RATE_POLLED,
	"A taxa de atualização conforme relatada pelo driver de vídeo.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_SETTINGS,
      "Alterar as configurações de saída de vídeo.")
MSG_HASH(MENU_ENUM_SUBLABEL_WIFI_SETTINGS,
      "Analisar por redes sem fio e estabelecer uma conexão.")
MSG_HASH(MENU_ENUM_SUBLABEL_HELP_LIST,
      "Saiba mais sobre como o programa funciona.")
MSG_HASH(MSG_ADDED_TO_FAVORITES,
      "Adicionado aos favoritos")
MSG_HASH(MSG_RESET_CORE_ASSOCIATION,
      "A associação do núcleo de entrada da lista de reprodução foi redefinida.")      
MSG_HASH(MSG_APPENDED_DISK,
      "Disco anexado")
MSG_HASH(MSG_APPLICATION_DIR,
      "Diretório do aplicativo")
MSG_HASH(MSG_APPLYING_CHEAT,
      "Aplicando as alterações de Trapaças.")
MSG_HASH(MSG_APPLYING_SHADER,
      "Aplicando Shader")
MSG_HASH(MSG_AUDIO_MUTED,
      "Áudio mudo.")
MSG_HASH(MSG_AUDIO_UNMUTED,
      "Áudio mudo desativado.")
MSG_HASH(MSG_AUTOCONFIG_FILE_ERROR_SAVING,
      "Erro em salvar o arquivo de autoconfiguração.")
MSG_HASH(MSG_AUTOCONFIG_FILE_SAVED_SUCCESSFULLY,
      "Arquivo de autoconfiguração salvo com sucesso.")
MSG_HASH(MSG_AUTOSAVE_FAILED,
      "Não foi possível inicializar o salvamento automático.")
MSG_HASH(MSG_AUTO_SAVE_STATE_TO,
      "Salvar Automaticamente Estado de Jogo em")
MSG_HASH(MSG_BLOCKING_SRAM_OVERWRITE,
      "Bloqueando Sobrescrita da SRAM")
MSG_HASH(MSG_BRINGING_UP_COMMAND_INTERFACE_ON_PORT,
      "Trazendo a interface de comando na porta")
MSG_HASH(MSG_BYTES,
      "bytes")
MSG_HASH(MSG_CANNOT_INFER_NEW_CONFIG_PATH,
      "Não é possível inferir o novo caminho de configuração. Use a hora atual.")
MSG_HASH(MSG_CHEEVOS_HARDCORE_MODE_ENABLE,
      "Modo Hardcore Habilitado, Estados de Jogo e Rebobinagem estão desabilitados.")
MSG_HASH(MSG_COMPARING_WITH_KNOWN_MAGIC_NUMBERS,
      "Comparando com números mágicos conhecidos...")
MSG_HASH(MSG_COMPILED_AGAINST_API,
      "Compilado contra a API")
MSG_HASH(MSG_CONFIG_DIRECTORY_NOT_SET,
      "Diretório de configuração não definido. Não foi possível salvar a nova configuração.")
MSG_HASH(MSG_CONNECTED_TO,
      "Conectado a")
MSG_HASH(MSG_CONTENT_CRC32S_DIFFER,
      "O CRC32 dos conteúdos difere. Não é possível utilizar jogos diferentes.")
MSG_HASH(MSG_CONTENT_LOADING_SKIPPED_IMPLEMENTATION_WILL_DO_IT,
      "Carregamento de conteúdo ignorado. A implementação irá carregar por conta própria.")
MSG_HASH(MSG_CORE_DOES_NOT_SUPPORT_SAVESTATES,
      "O núcleo não suporta Estados de Jogo.")
MSG_HASH(MSG_CORE_OPTIONS_FILE_CREATED_SUCCESSFULLY,
      "O arquivo de opções de núcleo foi criado com sucesso.")
MSG_HASH(MSG_COULD_NOT_FIND_ANY_NEXT_DRIVER,
      "Não foi possível encontrar nenhum driver seguinte")
MSG_HASH(MSG_COULD_NOT_FIND_COMPATIBLE_SYSTEM,
      "Não foi possível encontrar um sistema compatível.")
MSG_HASH(MSG_COULD_NOT_FIND_VALID_DATA_TRACK,
      "Não foi possível encontrar uma faixa de dados válida")
MSG_HASH(MSG_COULD_NOT_OPEN_DATA_TRACK,
      "Não foi possível abrir a faixa de dados")
MSG_HASH(MSG_COULD_NOT_READ_CONTENT_FILE,
      "Não foi possível ler o arquivo de conteúdo")
MSG_HASH(MSG_COULD_NOT_READ_MOVIE_HEADER,
      "Não foi possível ler o cabeçalho do filme.")
MSG_HASH(MSG_COULD_NOT_READ_STATE_FROM_MOVIE,
      "Não foi possível ler o Estado de Jogo do filme.")
MSG_HASH(MSG_CRC32_CHECKSUM_MISMATCH,
      "Soma de verificação CRC32 incompatível entre o arquivo de conteúdo e a soma de verificação de conteúdo salva no cabeçalho do arquivo de reprodução. Reprodução altamente susceptível de dessincronizar na reprodução.")
MSG_HASH(MSG_CUSTOM_TIMING_GIVEN,
      "Tempo personalizado fornecido")
MSG_HASH(MSG_DECOMPRESSION_ALREADY_IN_PROGRESS,
      "Descompressão já está em andamento.")
MSG_HASH(MSG_DECOMPRESSION_FAILED,
      "Descompressão falhou.")
MSG_HASH(MSG_DETECTED_VIEWPORT_OF,
      "Detectada janela de exibição de")
MSG_HASH(MSG_DID_NOT_FIND_A_VALID_CONTENT_PATCH,
      "Não encontrou uma modificação de conteúdo válido.")
MSG_HASH(MSG_DISCONNECT_DEVICE_FROM_A_VALID_PORT,
      "Desconectar dispositivo de uma porta válida.")
MSG_HASH(MSG_DISK_CLOSED,
      "Fechado")
MSG_HASH(MSG_DISK_EJECTED,
      "Ejetado")
MSG_HASH(MSG_DOWNLOADING,
      "Baixando")
MSG_HASH(MSG_INDEX_FILE,
      "index")
MSG_HASH(MSG_DOWNLOAD_FAILED,
      "Download falhou")
MSG_HASH(MSG_ERROR,
      "Erro")
MSG_HASH(MSG_ERROR_LIBRETRO_CORE_REQUIRES_CONTENT,
      "O núcleo libretro requer conteúdo, mas nada foi fornecido.")
MSG_HASH(MSG_ERROR_LIBRETRO_CORE_REQUIRES_SPECIAL_CONTENT,
      "O núcleo libretro requer conteúdo especial, mas nenhum foi fornecido.")
MSG_HASH(MSG_ERROR_PARSING_ARGUMENTS,
      "Erro em analisar os argumentos.")
MSG_HASH(MSG_ERROR_SAVING_CORE_OPTIONS_FILE,
      "Erro em salvar o arquivo de opções de núcleo.")
MSG_HASH(MSG_ERROR_SAVING_REMAP_FILE,
      "Erro em salvar o arquivo de remapeamento.")
MSG_HASH(MSG_ERROR_REMOVING_REMAP_FILE,
      "Erro em remover o arquivo de remapeamento.")
MSG_HASH(MSG_ERROR_SAVING_SHADER_PRESET,
      "Erro em salvar a predefinição de Shader.")
MSG_HASH(MSG_EXTERNAL_APPLICATION_DIR,
      "Diretório de Aplicativo Externo")
MSG_HASH(MSG_EXTRACTING,
      "Extraindo")
MSG_HASH(MSG_EXTRACTING_FILE,
      "Extraindo arquivo")
MSG_HASH(MSG_FAILED_SAVING_CONFIG_TO,
      "Falha em salvar a configuração em")
MSG_HASH(MSG_FAILED_TO,
      "Falha em")
MSG_HASH(MSG_FAILED_TO_ACCEPT_INCOMING_SPECTATOR,
      "Falha em aceitar o espectador ingresso.")
MSG_HASH(MSG_FAILED_TO_ALLOCATE_MEMORY_FOR_PATCHED_CONTENT,
      "Falha em alocar memória para o conteúdo modificado...")
MSG_HASH(MSG_FAILED_TO_APPLY_SHADER,
      "Falha em aplicar o Shader.")
MSG_HASH(MSG_FAILED_TO_BIND_SOCKET,
      "Falha em vincular o soquete.")
MSG_HASH(MSG_FAILED_TO_CREATE_THE_DIRECTORY,
      "Falha em criar o diretório.")
MSG_HASH(MSG_FAILED_TO_EXTRACT_CONTENT_FROM_COMPRESSED_FILE,
      "Falha em extrair o conteúdo do arquivo comprimido")
MSG_HASH(MSG_FAILED_TO_GET_NICKNAME_FROM_CLIENT,
      "Falha em obter o apelido do cliente.")
MSG_HASH(MSG_FAILED_TO_LOAD,
      "Falha em carregar")
MSG_HASH(MSG_FAILED_TO_LOAD_CONTENT,
      "Falha em carregar o conteúdo")
MSG_HASH(MSG_FAILED_TO_LOAD_MOVIE_FILE,
      "Falha em carregar o arquivo de filme")
MSG_HASH(MSG_FAILED_TO_LOAD_OVERLAY,
      "Falha em carregar a Transparência.")
MSG_HASH(MSG_FAILED_TO_LOAD_STATE,
      "Falha em carregar o Estado de Jogo de")
MSG_HASH(MSG_FAILED_TO_OPEN_LIBRETRO_CORE,
      "Falha em abrir o núcleo Libretro")
MSG_HASH(MSG_FAILED_TO_PATCH,
      "Falha em executar a modificação")
MSG_HASH(MSG_FAILED_TO_RECEIVE_HEADER_FROM_CLIENT,
      "Falha em receber o cabeçalho do cliente.")
MSG_HASH(MSG_FAILED_TO_RECEIVE_NICKNAME,
      "Falha em receber o apelido.")
MSG_HASH(MSG_FAILED_TO_RECEIVE_NICKNAME_FROM_HOST,
      "Falha em receber o apelido do hospedeiro.")
MSG_HASH(MSG_FAILED_TO_RECEIVE_NICKNAME_SIZE_FROM_HOST,
      "Falha em receber o tamanho do apelido do hospedeiro.")
MSG_HASH(MSG_FAILED_TO_RECEIVE_SRAM_DATA_FROM_HOST,
      "Falha em receber os dados SRAM do hospedeiro.")
MSG_HASH(MSG_FAILED_TO_REMOVE_DISK_FROM_TRAY,
      "Falha em remover o disco da bandeja.")
MSG_HASH(MSG_FAILED_TO_REMOVE_TEMPORARY_FILE,
      "Falha em remover o arquivo temporário")
MSG_HASH(MSG_FAILED_TO_SAVE_SRAM,
      "Falha em salvar SRAM")
MSG_HASH(MSG_FAILED_TO_SAVE_STATE_TO,
      "Falha em salvar o Estado de Jogo em")
MSG_HASH(MSG_FAILED_TO_SEND_NICKNAME,
      "Falha em enviar o apelido.")
MSG_HASH(MSG_FAILED_TO_SEND_NICKNAME_SIZE,
      "Falha em enviar o tamanho do apelido.")
MSG_HASH(MSG_FAILED_TO_SEND_NICKNAME_TO_CLIENT,
      "Falha em enviar o apelido para o cliente.")
MSG_HASH(MSG_FAILED_TO_SEND_NICKNAME_TO_HOST,
      "Falha em enviar o apelido para o hospedeiro.")
MSG_HASH(MSG_FAILED_TO_SEND_SRAM_DATA_TO_CLIENT,
      "Falha em enviar os dados SRAM para o cliente.")
MSG_HASH(MSG_FAILED_TO_START_AUDIO_DRIVER,
      "Falha em iniciar o driver de áudio. Prosseguindo sem áudio.")
MSG_HASH(MSG_FAILED_TO_START_MOVIE_RECORD,
      "Falha em iniciar a gravação do filme.")
MSG_HASH(MSG_FAILED_TO_START_RECORDING,
      "Falha em iniciar a gravação.")
MSG_HASH(MSG_FAILED_TO_TAKE_SCREENSHOT,
      "Falha em obter uma captura de tela.")
MSG_HASH(MSG_FAILED_TO_UNDO_LOAD_STATE,
      "Falha em desfazer o carregamento de Estado de Jogo.")
MSG_HASH(MSG_FAILED_TO_UNDO_SAVE_STATE,
      "Falha em desfazer o salvamento de Estado de Jogo.")
MSG_HASH(MSG_FAILED_TO_UNMUTE_AUDIO,
      "Falha em desativar o áudio mudo.")
MSG_HASH(MSG_FATAL_ERROR_RECEIVED_IN,
      "Erro fatal recebido em")
MSG_HASH(MSG_FILE_NOT_FOUND,
      "Arquivo não encontrado")
MSG_HASH(MSG_FOUND_AUTO_SAVESTATE_IN,
      "Estado de Jogo automático encontrado em")
MSG_HASH(MSG_FOUND_DISK_LABEL,
      "Rótulo de disco encontrado")
MSG_HASH(MSG_FOUND_FIRST_DATA_TRACK_ON_FILE,
      "Encontrada primeira faixa de dados no arquivo")
MSG_HASH(MSG_FOUND_LAST_STATE_SLOT,
      "Encontrada último compartimento de Estado de Jogo")
MSG_HASH(MSG_FOUND_SHADER,
      "Shader encontrado")
MSG_HASH(MSG_FRAMES,
      "Quadros")
MSG_HASH(MSG_GAME_SPECIFIC_CORE_OPTIONS_FOUND_AT,
      "Opções por Jogo: Opções de núcleo específicas do jogo encontradas em")
MSG_HASH(MSG_GOT_INVALID_DISK_INDEX,
      "Índice de disco inválido obtido")
MSG_HASH(MSG_GRAB_MOUSE_STATE,
      "Capturar estado do Mouse")
MSG_HASH(MSG_GAME_FOCUS_ON,
      "Foco do jogo ligado")
MSG_HASH(MSG_GAME_FOCUS_OFF,
      "Foco do jogo desligado")
MSG_HASH(MSG_HW_RENDERED_MUST_USE_POSTSHADED_RECORDING,
      "O núcleo libretro é renderizado por hardware. Deve usar a gravação pós-Shader também.")
MSG_HASH(MSG_INFLATED_CHECKSUM_DID_NOT_MATCH_CRC32,
      "A soma de verificação inflada não corresponde ao CRC32.")
MSG_HASH(MSG_INPUT_CHEAT,
      "Entrada de Trapaça")
MSG_HASH(MSG_INPUT_CHEAT_FILENAME,
      "Nome do Arquivo de Trapaça")
MSG_HASH(MSG_INPUT_PRESET_FILENAME,
      "Nome de Arquivo de Predefinição")
MSG_HASH(MSG_INPUT_RENAME_ENTRY,
      "Renomear Título")
MSG_HASH(MSG_INTERFACE,
      "Interface")
MSG_HASH(MSG_INTERNAL_STORAGE,
      "Armazenamento Interno")
MSG_HASH(MSG_REMOVABLE_STORAGE,
      "Armazenamento Removível")
MSG_HASH(MSG_INVALID_NICKNAME_SIZE,
      "Tamanho de apelido inválido.")
MSG_HASH(MSG_IN_BYTES,
      "em bytes")
MSG_HASH(MSG_IN_GIGABYTES,
      "em gigabytes")
MSG_HASH(MSG_IN_MEGABYTES,
      "em megabytes")
MSG_HASH(MSG_LIBRETRO_ABI_BREAK,
      "foi compilado contra uma versão diferente do libretro do que esta.")
MSG_HASH(MSG_LIBRETRO_FRONTEND,
      "Frontend para Libretro")
MSG_HASH(MSG_LOADED_STATE_FROM_SLOT,
      "Estado de Jogo carregado do compartimento #%d.")
MSG_HASH(MSG_LOADED_STATE_FROM_SLOT_AUTO,
      "Estado de Jogo carregado do compartimento #-1 (automático).")
MSG_HASH(MSG_LOADING,
      "Carregando")
MSG_HASH(MSG_FIRMWARE,
      "Um ou mais arquivos de firmware estão faltando")
MSG_HASH(MSG_LOADING_CONTENT_FILE,
      "Carregando arquivo de conteúdo")
MSG_HASH(MSG_LOADING_HISTORY_FILE,
      "Carregando arquivo de histórico")
MSG_HASH(MSG_LOADING_STATE,
      "Carregando Estado de Jogo")
MSG_HASH(MSG_MEMORY,
      "Memória")
MSG_HASH(MSG_MOVIE_FILE_IS_NOT_A_VALID_BSV1_FILE,
      "O arquivo de filme não é um arquivo BSV1 válido.")
MSG_HASH(MSG_MOVIE_FORMAT_DIFFERENT_SERIALIZER_VERSION,
      "O formato de filme parece ter uma versão de serializador diferente. Provavelmente irá falhar.")
MSG_HASH(MSG_MOVIE_PLAYBACK_ENDED,
      "Reprodução de filme terminou.")
MSG_HASH(MSG_MOVIE_RECORD_STOPPED,
      "Parando a gravação de filme.")
MSG_HASH(MSG_NETPLAY_FAILED,
      "Falha em inicializar o Netplay.")
MSG_HASH(MSG_NO_CONTENT_STARTING_DUMMY_CORE,
      "Sem conteúdo, iniciando um núcleo modelo.")
MSG_HASH(MSG_NO_SAVE_STATE_HAS_BEEN_OVERWRITTEN_YET,
      "Nenhum Estado de Jogo foi sobrescrito até o momento.")
MSG_HASH(MSG_NO_STATE_HAS_BEEN_LOADED_YET,
      "Nenhum Estado de Jogo foi carregado até o momento.")
MSG_HASH(MSG_OVERRIDES_ERROR_SAVING,
      "Erro em salvar as redefinições.")
MSG_HASH(MSG_OVERRIDES_SAVED_SUCCESSFULLY,
      "Redefinições salvas com sucesso.")
MSG_HASH(MSG_PAUSED,
      "Pausado.")
MSG_HASH(MSG_PROGRAM,
      "RetroArch")
MSG_HASH(MSG_READING_FIRST_DATA_TRACK,
      "Lendo a primeira faixa de dados...")
MSG_HASH(MSG_RECEIVED,
      "recebido")
MSG_HASH(MSG_RECORDING_TERMINATED_DUE_TO_RESIZE,
      "A gravação terminou devido ao redimensionamento.")
MSG_HASH(MSG_RECORDING_TO,
      "Gravando em")
MSG_HASH(MSG_REDIRECTING_CHEATFILE_TO,
      "Redirecionando o arquivo de Trapaça em")
MSG_HASH(MSG_REDIRECTING_SAVEFILE_TO,
      "Redirecionando o Jogo-Salvo em")
MSG_HASH(MSG_REDIRECTING_SAVESTATE_TO,
      "Redirecionando o Estado de Jogo em")
MSG_HASH(MSG_REMAP_FILE_SAVED_SUCCESSFULLY,
      "Arquivo de remapeamento salvo com sucesso.")
MSG_HASH(MSG_REMAP_FILE_REMOVED_SUCCESSFULLY,
      "Arquivo de remapeamento salvo com sucesso.")
MSG_HASH(MSG_REMOVED_DISK_FROM_TRAY,
      "Disco removido da bandeja.")
MSG_HASH(MSG_REMOVING_TEMPORARY_CONTENT_FILE,
      "Removendo arquivo de conteúdo temporário")
MSG_HASH(MSG_RESET,
      "Reinicializar")
MSG_HASH(MSG_RESTARTING_RECORDING_DUE_TO_DRIVER_REINIT,
      "Reiniciando a gravação devido ao reinício do driver.")
MSG_HASH(MSG_RESTORED_OLD_SAVE_STATE,
      "Estado de Jogo antigo restaurado.")
MSG_HASH(MSG_RESTORING_DEFAULT_SHADER_PRESET_TO,
      "Shaders: restaurando predefinição padrão de Shader em")
MSG_HASH(MSG_REVERTING_SAVEFILE_DIRECTORY_TO,
      "Revertendo diretório de Jogo-Salvo em")
MSG_HASH(MSG_REVERTING_SAVESTATE_DIRECTORY_TO,
      "Revertendo diretório de Estado de Jogo em")
MSG_HASH(MSG_REWINDING,
      "Voltando atrás.")
MSG_HASH(MSG_REWIND_INIT,
      "Inicializando o buffer de Rebobinagem com tamanho")
MSG_HASH(MSG_REWIND_INIT_FAILED,
      "Falha em inicializar o buffer de Rebobinagem. Rebobinagem será desativado.")
MSG_HASH(MSG_REWIND_INIT_FAILED_THREADED_AUDIO,
      "Esta implementação usa áudio paralelizado. Não é possível utilizar Rebobinagem.")
MSG_HASH(MSG_REWIND_REACHED_END,
      "Final do buffer de Rebobinagem atingido.")
MSG_HASH(MSG_SAVED_NEW_CONFIG_TO,
      "Nova configuração salva em")
MSG_HASH(MSG_SAVED_STATE_TO_SLOT,
      "Estado de Jogo salvo no compartimento #%d.")
MSG_HASH(MSG_SAVED_STATE_TO_SLOT_AUTO,
      "Estado de Jogo salvo no compartimento #-1 (automático).")
MSG_HASH(MSG_SAVED_SUCCESSFULLY_TO,
      "Salvo com sucesso em")
MSG_HASH(MSG_SAVING_RAM_TYPE,
      "Salvando Tipo de RAM")
MSG_HASH(MSG_SAVING_STATE,
      "Salvando Estado de Jogo")
MSG_HASH(MSG_SCANNING,
      "Analisando")
MSG_HASH(MSG_SCANNING_OF_DIRECTORY_FINISHED,
      "Análise de diretório terminada")
MSG_HASH(MSG_SENDING_COMMAND,
      "Enviando comando")
MSG_HASH(MSG_SEVERAL_PATCHES_ARE_EXPLICITLY_DEFINED,
      "Várias modificações de conteúdo estão explicitamente definidas, ignorando todas...")
MSG_HASH(MSG_SHADER,
      "Shader")
MSG_HASH(MSG_SHADER_PRESET_SAVED_SUCCESSFULLY,
      "Predefinição de Shader salva com sucesso.")
MSG_HASH(MSG_SKIPPING_SRAM_LOAD,
      "Ignorando carregamento da SRAM.")
MSG_HASH(MSG_SLOW_MOTION,
      "Câmera Lenta.")
MSG_HASH(MSG_FAST_FORWARD,
       "Avanço rápido.")
MSG_HASH(MSG_SLOW_MOTION_REWIND,
      "Rebobinagem em Câmera Lenta.")
MSG_HASH(MSG_SRAM_WILL_NOT_BE_SAVED,
      "SRAM não será salva.")
MSG_HASH(MSG_STARTING_MOVIE_PLAYBACK,
      "Iniciando reprodução de filme.")
MSG_HASH(MSG_STARTING_MOVIE_RECORD_TO,
      "Iniciando a gravação de filme em")
MSG_HASH(MSG_STATE_SIZE,
      "Tamanho do Estado de Jogo")
MSG_HASH(MSG_STATE_SLOT,
      "Compartimento do Estado de Jogo")
MSG_HASH(MSG_TAKING_SCREENSHOT,
      "Fazendo captura de tela")
MSG_HASH(MSG_TO,
      "em")
MSG_HASH(MSG_UNDID_LOAD_STATE,
      "Desfez o carregamento de Estado de Jogo.")
MSG_HASH(MSG_UNDOING_SAVE_STATE,
      "Desfazendo o salvamento de Estado de Jogo")
MSG_HASH(MSG_UNKNOWN,
      "Desconhecido")
MSG_HASH(MSG_UNPAUSED,
      "Retomando.")
MSG_HASH(MSG_UNRECOGNIZED_COMMAND,
      "Comando não reconhecido")
MSG_HASH(MSG_USING_CORE_NAME_FOR_NEW_CONFIG,
      "Usando o nome do núcleo para uma nova configuração.")
MSG_HASH(MSG_USING_LIBRETRO_DUMMY_CORE_RECORDING_SKIPPED,
      "Usando o núcleo libretro modelo. Pulando a gravação.")
MSG_HASH(MSG_VALUE_CONNECT_DEVICE_FROM_A_VALID_PORT,
      "Conecte o dispositivo a partir de uma porta válida.")
MSG_HASH(MSG_VALUE_DISCONNECTING_DEVICE_FROM_PORT,
      "Desconectando o dispositivo da porta")
MSG_HASH(MSG_VALUE_REBOOTING,
      "Reinicializando...")
MSG_HASH(MSG_VALUE_SHUTTING_DOWN,
      "Desligando...")
MSG_HASH(MSG_VERSION_OF_LIBRETRO_API,
      "Versão da API libretro")
MSG_HASH(MSG_VIEWPORT_SIZE_CALCULATION_FAILED,
      "Falha no cálculo de tamanho da janela de exibição! Prosseguindo usando dados brutos. Isto provavelmente não funcionará corretamente...")
MSG_HASH(MSG_VIRTUAL_DISK_TRAY,
      "bandeja de disco virtual.")
MSG_HASH(MENU_ENUM_SUBLABEL_AUDIO_LATENCY,
      "Latência de áudio desejada em milissegundos. Pode não ser honrado se o driver de áudio não puder prover a latência desejada.")
MSG_HASH(MENU_ENUM_SUBLABEL_AUDIO_MUTE,
      "Áudio mudo/não-mudo.")
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUDIO_RATE_CONTROL_DELTA,
      "Ajuda a suavizar as imperfeições na regulagem ao sincronizar áudio e vídeo. Esteja ciente que se desativado, será quase impossível de se obter a sincronia adequada."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_CAMERA_ALLOW,
      "Permitir ou não o acesso à câmera pelos núcleos."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_LOCATION_ALLOW,
      "Permitir ou não o acesso ao serviço de localização pelos núcleos."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_INPUT_MAX_USERS,
      "Número máximo de usuários suportados pelo RetroArch."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_INPUT_POLL_TYPE_BEHAVIOR,
      "Influencia como a chamada seletiva de entrada é feita dentro do RetroArch. Definindo com 'Cedo' ou 'Tarde' pode resultar em menos latência, dependendo da sua configuração."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_INPUT_ALL_USERS_CONTROL_MENU,
      "Permitir a qualquer usuário controlar o menu. Se desabilitado, apenas o Usuário 1 poderá controlar o menu."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUDIO_VOLUME,
      "Volume do áudio (em dB). 0dB é o volume normal, e nenhum ganho é aplicado."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUDIO_WASAPI_EXCLUSIVE_MODE,
      "Permitir ao driver WASAPI obter controle exclusivo do dispositivo de áudio. Se desativado, o modo compartilhado será utilizado."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUDIO_WASAPI_FLOAT_FORMAT,
      "Utilizar formato de ponto flutuante para o driver WASAPI, se suportado pelo dispositivo de áudio."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUDIO_WASAPI_SH_BUFFER_LENGTH,
      "O tamanho (em quadros) do buffer intermediário quando o driver WASAPI estiver em modo compartilhado."
      )
MSG_HASH(
   MENU_ENUM_SUBLABEL_AUDIO_SYNC,
      "Sincroniza o áudio. Recomendado."
   )
MSG_HASH(
   MENU_ENUM_SUBLABEL_INPUT_AXIS_THRESHOLD,
      "Até que ponto um eixo deve ser movido para resultar em um botão pressionado."
   )
MSG_HASH(
   MENU_ENUM_SUBLABEL_INPUT_BIND_TIMEOUT,
      "Quantidade de segundos para aguardar até proceder para o próximo vínculo."
   )
MSG_HASH(
   MENU_ENUM_SUBLABEL_INPUT_TURBO_PERIOD,
      "Descreve o período quando os botões com turbo habilitado são alternados. Os números são descritos em quadros."
   )
MSG_HASH(
   MENU_ENUM_SUBLABEL_INPUT_DUTY_CYCLE,
      "Descreve quão longo deve ser o período de um botão com turbo habilitado. Os números são descritos como quadros."
   )
MSG_HASH(
   MENU_ENUM_SUBLABEL_VIDEO_VSYNC,
      "Sincroniza o vídeo de saída da placa gráfica com a taxa de atualização da tela. Recomendado."
   )
MSG_HASH(
   MENU_ENUM_SUBLABEL_VIDEO_ALLOW_ROTATE,
      "Permite que os núcleos definam a rotação. Quando desabilitado, as requisições de rotação são ignoradas. Útil para configurações onde se rotaciona manualmente a tela."
   )
MSG_HASH(
   MENU_ENUM_SUBLABEL_DUMMY_ON_CORE_SHUTDOWN,
      "Alguns núcleos podem ter um recurso de desligamento. Se habilitado, impedirá que o núcleo feche o RetroArch. Em vez disto, carrega um núcleo modelo."
   )
MSG_HASH(
   MENU_ENUM_SUBLABEL_CHECK_FOR_MISSING_FIRMWARE,
      "Verifica se todos os firmwares necessários estão presentes antes de tentar carregar conteúdo."
   )
MSG_HASH(
   MENU_ENUM_SUBLABEL_VIDEO_REFRESH_RATE,
      "Taxa de atualização vertical da sua tela. Utilizado para calcular uma taxa de saída de áudio adequada. OBS: Isto será ignorado se a função 'Vídeo Paralelizado' estiver habilitada."
   )
MSG_HASH(
   MENU_ENUM_SUBLABEL_AUDIO_ENABLE,
      "Habilita a saída de áudio."
   )
MSG_HASH(
   MENU_ENUM_SUBLABEL_AUDIO_MAX_TIMING_SKEW,
      "Mudança máxima na taxa de entrada de áudio. Se aumentado habilita grandes mudanças na regulagem ao custo de imprecisão no timbre do som (ex: rodando núcleos PAL em modo NTSC)."
   )
MSG_HASH(
   MSG_FAILED,
      "falhou"
   )
MSG_HASH(
   MSG_SUCCEEDED,
      "teve êxito"
   )
MSG_HASH(
   MSG_DEVICE_NOT_CONFIGURED,
      "não configurado"
   )
MSG_HASH(
   MSG_DEVICE_NOT_CONFIGURED_FALLBACK,
      "não configurado, usando reserva"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST,
      "Lista de Cursores da Base de Dados"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_DEVELOPER,
      "Base de Dados - Filtro : Desenvolvedor"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_PUBLISHER,
      "Base de Dados - Filtro : Publicador"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VALUE_DISABLED,
      "Desabilitado"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VALUE_ENABLED,
      "Habilitado"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VALUE_CONTENT_HISTORY_PATH,
      "Caminho do Histórico de Conteúdo"
   )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_ORIGIN,
      "Base de Dados - Filtro : Origem")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_FRANCHISE,
      "Base de Dados - Filtro : Franquia")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_ESRB_RATING,
      "Base de Dados - Filtro : Classificação ESRB")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_ELSPA_RATING,
      "Base de Dados - Filtro : Classificação ELSPA")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_PEGI_RATING,
      "Base de Dados - Filtro : Classificação PEGI")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_CERO_RATING,
      "Base de Dados - Filtro : Classificação CERO")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_BBFC_RATING,
      "Base de Dados - Filtro : Classificação BBFC")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_MAX_USERS,
      "Base de Dados - Filtro : Usuários máximos")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_RELEASEDATE_BY_MONTH,
      "Base de Dados - Filtro : Data de Lançamento Por Mês")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_RELEASEDATE_BY_YEAR,
      "Base de Dados - Filtro : Data de Lançamento Por Ano")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_EDGE_MAGAZINE_ISSUE,
      "Base de Dados - Filtro : Edição da Revista Edge")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_EDGE_MAGAZINE_RATING,
      "Base de Dados - Filtro : Classificação da Revista Edge")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_DATABASE_INFO,
      "Informações da Base de Dados")
MSG_HASH(MSG_WIFI_SCAN_COMPLETE,
      "Análise de Wi-Fi completa.")
MSG_HASH(MSG_SCANNING_WIRELESS_NETWORKS,
      "Analisando redes sem fio...")
MSG_HASH(MSG_NETPLAY_LAN_SCAN_COMPLETE,
      "Análise de Netplay completa.")
MSG_HASH(MSG_NETPLAY_LAN_SCANNING,
      "Analisando por hospedeiros de Netplay...")
MSG_HASH(MENU_ENUM_SUBLABEL_PAUSE_NONACTIVE,
      "Pausar o jogo quando a janela do RetroArch não estiver ativa.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_DISABLE_COMPOSITION,
      "Habilitar ou desabilitar composição (Somente no Windows).")
MSG_HASH(MENU_ENUM_SUBLABEL_HISTORY_LIST_ENABLE,
      "Habilitar ou desabilitar a lista de reprodução recente para jogos, imagens, música e vídeos.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_HISTORY_SIZE,
      "Limita o número de itens da lista de reprodução recente para jogos, imagens, música e vídeos.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_UNIFIED_MENU_CONTROLS,
      "Controles de Menu Unificados")
MSG_HASH(MENU_ENUM_SUBLABEL_INPUT_UNIFIED_MENU_CONTROLS,
      "Utilizar os mesmos controles para o menu e jogo. Aplica-se ao teclado.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_FONT_ENABLE,
      "Exibir mensagens na tela.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETWORK_USER_REMOTE_ENABLE,
      "Habilitar Remoto do Usuário %d")
MSG_HASH(MENU_ENUM_LABEL_VALUE_BATTERY_LEVEL_ENABLE,
      "Exibir nível de bateria")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SELECT_FILE,
      "Selecionar Arquivo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SELECT_FROM_COLLECTION,
      "Selecionar de Coleção")
MSG_HASH(MENU_ENUM_LABEL_VALUE_FILTER,
      "Filtro")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SCALE,
      "Escala")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_START_WHEN_LOADED,
      "O Netplay irá iniciar quando o conteúdo for carregado.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_LOAD_CONTENT_MANUALLY,
      "Não foi possível encontrar um núcleo adequado ou arquivo de conteúdo, carregue manualmente.")
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BROWSE_URL_LIST,
      "Navegar pela URL"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BROWSE_URL,
      "Caminho da URL"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BROWSE_START,
      "Iniciar"
      )
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHADER_PIPELINE_BOKEH,
      "Bokeh")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHADER_PIPELINE_SNOWFLAKE,
      "Floco de neve")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_REFRESH_ROOMS,
      "Atualizar Lista de Salas")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_ROOM_NICKNAME,
      "Apelido: %s")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_ROOM_NICKNAME_LAN,
      "Apelido (lan): %s")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_COMPAT_CONTENT_FOUND,
      "Conteúdo compatível encontrado")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_CROP_OVERSCAN,
      "Corta alguns pixels ao redor das bordas da imagem habitualmente deixada em branco por desenvolvedores, que por vezes também contêm pixels de lixo.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_SMOOTH,
      "Adiciona um leve embaciado à imagem para suavizar as arestas da borda dos pixels. Esta opção tem pouco impacto no desempenho.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_FILTER,
      "Aplica um filtro de vídeo processado pela CPU. OBS: Pode vir a um alto custo de desempenho. Alguns filtros de vídeo podem funcionar apenas para núcleos que usam cores de 32 bits ou 16 bits.")
MSG_HASH(MENU_ENUM_SUBLABEL_CHEEVOS_USERNAME,
      "Insira o nome de usuário de sua conta Retro Achievements.")
MSG_HASH(MENU_ENUM_SUBLABEL_CHEEVOS_PASSWORD,
      "Insira a senha de sua conta Retro Achievements.")
MSG_HASH(MENU_ENUM_SUBLABEL_NETPLAY_NICKNAME,
      "Insira seu nome de usuário aqui. Isto será utilizado para sessões do Netplay, entre outras coisas.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_POST_FILTER_RECORD,
      "Capturar a imagem depois que os filtros (mas não os Shaders) forem aplicados. Seu vídeo ficará tão elegante quanto o que você vê na tela.")
MSG_HASH(MENU_ENUM_SUBLABEL_CORE_LIST,
      "Selecionar qual núcleo utilizar.")
MSG_HASH(MENU_ENUM_SUBLABEL_LOAD_CONTENT_LIST,
      "Selecionar qual conteúdo iniciar.")
MSG_HASH(MENU_ENUM_SUBLABEL_NETWORK_INFORMATION,
      "Exibir interfaces de rede e endereços de IP associados.")
MSG_HASH(MENU_ENUM_SUBLABEL_SYSTEM_INFORMATION,
      "Exibir informações específicas do dispositivo.")
MSG_HASH(MENU_ENUM_SUBLABEL_QUIT_RETROARCH,
      "Sair do programa.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_WINDOW_WIDTH,
      "Define a largura personalizada para a janela de exibição. Deixado em 0 a janela irá dimensionar o mais largo possível.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_WINDOW_HEIGHT,
      "Define a altura personalizada para a janela de exibição. Deixado em 0 a janela irá dimensionar o mais alto possível.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_FULLSCREEN_X,
      "Define a largura personalizada para o modo de tela cheia em não-janela. Deixar em 0 irá usar a resolução da área de trabalho.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_FULLSCREEN_Y,
      "Define a altura personalizada para o modo de tela cheia em não-janela. Deixar em 0 irá usar a resolução da área de trabalho.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_MESSAGE_POS_X,
      "Especifique a posição personalizada no eixo X para o texto na tela.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_MESSAGE_POS_Y,
      "Especifique a posição personalizada no eixo Y para o texto na tela.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_FONT_SIZE,
      "Especifique o tamanho da fonte em pontos.")
MSG_HASH(MENU_ENUM_SUBLABEL_INPUT_OVERLAY_HIDE_IN_MENU,
      "Ocultar a Transparência enquanto estiver dentro do menu e exibir novamente ao sair.")
MSG_HASH(MENU_ENUM_SUBLABEL_INPUT_OVERLAY_SHOW_PHYSICAL_INPUTS,
      "Exibir comandos de teclado/controle na transparência.")
MSG_HASH(MENU_ENUM_SUBLABEL_INPUT_OVERLAY_SHOW_PHYSICAL_INPUTS_PORT,
      "Selecione a porta para a transparência escutar se Exibir Comandos na Transparência estiver habilitado.")
MSG_HASH(
      MENU_ENUM_SUBLABEL_CONTENT_COLLECTION_LIST,
      "O conteúdo analisado aparecerá aqui."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_SCALE_INTEGER,
      "Apenas dimensiona o vídeo em valores inteiros. O tamanho de base depende da geometria relatada pelo sistema e da proporção de tela. Se 'Forçar Proporção' não estiver definido, X / Y serão dimensionados independentemente em valores inteiros."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_GPU_SCREENSHOT,
      "Captura a tela com Shader de GPU se disponível."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_ROTATION,
      "Força uma certa rotação da tela. A rotação é adicionada a rotação que o núcleo definir."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_FORCE_SRGB_DISABLE,
      "Desabilita de forma forçada o suporte sRGB FBO. Alguns drivers Intel OpenGL no Windows possuem problemas de vídeo com o suporte sRGB FBO se estiver habilitado. Habilitando isto pode contornar o problema."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_FULLSCREEN,
      "Inicia em tela cheia. Pode ser mudado a qualquer momento."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_WINDOWED_FULLSCREEN,
      "Se estiver em tela cheia, prefira utilizar uma janela de tela cheia."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_GPU_RECORD,
      "Grava o material de saída do Shader de GPU se disponível."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_SAVESTATE_AUTO_INDEX,
      "Ao criar um Estado de Jogo, o índice do Estado de Jogo é aumentado automaticamente antes de ser salvo. Ao carregar um conteúdo, o índice será definido para o índice mais alto existente."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_BLOCK_SRAM_OVERWRITE,
      "Bloqueia a SRAM de ser sobrescrita ao carregar um Estado de Jogo. Pode causar problemas no jogo."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_FASTFORWARD_RATIO,
      "Taxa máxima em que o conteúdo será executado quando utilizado o Avanço Rápido (ex: 5.0x para conteúdos em 60fps = 300 fps máx). Se for definido como 0.0x, a taxa de Avanço Rápido é ilimitada (sem FPS máx)."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_SLOWMOTION_RATIO,
      "Quando está em Câmera Lenta, o conteúdo será diminuído pelo fator especificado/definido."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_RUN_AHEAD_ENABLED,
      "Executar o núcleo lógico um ou mais quadros à frente e carreguar o estado de volta para reduzir o atraso dos controles percebido."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_RUN_AHEAD_FRAMES,
      "O número de quadros para avançar. Causa problemas de jogabilidade, como instabilidade, se você exceder o número de quadros de atraso internos do jogo."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_RUN_AHEAD_SECONDARY_INSTANCE,
      "Usa uma segunda instância do núcleo do RetroArch para avançar. Evita problemas de áudio devido ao estado de carregamento."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_REWIND_ENABLE,
      "Habilita a Rebobinagem. Isso irá impactar o desempenho ao jogar."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_REWIND_GRANULARITY,
      "Ao definir um número de quadros para Rebobinagem, você pode retroceder vários quadros de uma só vez, aumentando a velocidade da função."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_LIBRETRO_LOG_LEVEL,
      "Define o nível de registro de eventos para os núcleos. Se o nível do registro enviado por um núcleo for abaixo deste valor, o mesmo é ignorado."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_PERFCNT_ENABLE,
      "Habilitar os contadores de desempenho para o RetroArch (e núcleos)."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_SAVESTATE_AUTO_SAVE,
      "Cria automaticamente um Estado de Jogo no final da execução do RetroArch. O RetroArch irá carregar automaticamente este Estado de Jogo se a função 'Autocarregar Estado de Jogo' estiver habilitada."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_SAVESTATE_AUTO_LOAD,
      "Carrega automaticamente o último Estado de Jogo auto salvo na inicialização do RetroArch."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_SAVESTATE_THUMBNAIL_ENABLE,
      "Mostrar miniaturas de estados salvos dentro do menu."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUTOSAVE_INTERVAL,
      "Salvar automaticamente o Save RAM não-volátil em um intervalo regular. Isso está desabilitado por padrão, a menos que seja definido de outra forma. O intervalo é medido em segundos. Um valor de 0 desativa o salvamento automático."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_INPUT_REMAP_BINDS_ENABLE,
      "Se ativado, substitui os vínculos de entrada com as associações remapeadas definidas para o núcleo atual."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_INPUT_AUTODETECT_ENABLE,
      "Habilita a detecção automática de entrada. Tentará configurar automaticamente joypads, estilo Plug-and-Play."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_MENU_INPUT_SWAP_OK_CANCEL,
      "Troca de botões para OK/Cancelar. Desabilitado é o estilo de botão japonês, habilitada é oestilo ocidental."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_PAUSE_LIBRETRO,
      "Se desabilitado, o conteúdo continuará sendo executado em segundo plano quando o menu do RetroArch for alternado."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_DRIVER,
      "Driver de vídeo para usar."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUDIO_DRIVER,
      "Driver de áudio para usar."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_INPUT_DRIVER,
      "Driver de entrada para usar. Dependendo do driver de vídeo, pode forçar um driver de entrada diferente."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_JOYPAD_DRIVER,
      "Driver do Joypad para usar."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUDIO_RESAMPLER_DRIVER,
      "Driver de reamostragem de áudio a ser utilizado."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_CAMERA_DRIVER,
      "Driver de câmera a ser utilizado."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_LOCATION_DRIVER,
      "Driver de localização a ser utilizado."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_MENU_DRIVER,
      "Driver de menu a ser utilizado."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_RECORD_DRIVER,
      "Driver de gravação a ser utilizado."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_WIFI_DRIVER,
      "Driver de WiFi a ser utilizado."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NAVIGATION_BROWSER_FILTER_SUPPORTED_EXTENSIONS_ENABLE,
      "Filtra os arquivos em exibição no explorador de arquivos por extensões suportadas."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_MENU_WALLPAPER,
      "Seleciona uma imagem para definir como plano de fundo do menu."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_DYNAMIC_WALLPAPER,
      "Carrega dinamicamente um novo plano de fundo dependendo do contexto."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUDIO_DEVICE,
      "Substitui o dispositivo de áudio padrão utilizado pelo driver de áudio. Isto depende do driver."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUDIO_DSP_PLUGIN,
      "Plugin DSP de Áudio que processa o áudio antes de ser enviado para o driver."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUDIO_OUTPUT_RATE,
      "Taxa de amostragem da saída de áudio."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_OVERLAY_OPACITY,
      "Opacidade de todos os elementos de interface da Transparência."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_OVERLAY_SCALE,
      "Escala de todos os elementos de interface da Transparência."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_INPUT_OVERLAY_ENABLE,
      "Habilita a Transparência."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_OVERLAY_PRESET,
      "Seleciona uma Transparência pelo navegador de arquivos."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_IP_ADDRESS,
      "Endereço do hospedeiro a se conectar."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_TCP_UDP_PORT,
      "Porta do endereço de IP do hospedeiro. Pode ser uma porta TCP ou uma porta UDP."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_PASSWORD,
      "Senha para conectar ao hospedeiro de Netplay. Utilizado apenas no modo hospedeiro."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_PUBLIC_ANNOUNCE,
      "Anunciar os jogos de Netplay publicamente. Se não for definido, os clientes deverão conectar manualmente em vez de usar o lobby público."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_SPECTATE_PASSWORD,
      "Senha para conectar ao hospedeiro de Netplay apenas com privilégios de espectador. Utilizado apenas no modo hospedeiro."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_START_AS_SPECTATOR,
      "Define se o Netplay deve iniciar em modo espectador."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_ALLOW_SLAVES,
      "Define se conexões em modo escravo são permitidas. Clientes em modo escravo requerem muito pouco poder de processamento em ambos os lados, mas irão sofrer significamente da latência de rede."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_REQUIRE_SLAVES,
      "Define se conexões que não estão em modo escravo são proibidas. Não recomendado, exceto para redes muito rápidas com máquinas muito lentas."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_STATELESS_MODE,
      "Define se deve executar o Netplay em modo que não utilize Estados de Jogo. Se definido como verdadeiro, uma rede muito rápida é necessária, mas Rebobinagem não é permitido, então não haverá oscilação no Netplay."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_CHECK_FRAMES,
      "Frequência em quadros no qual o Netplay verificará se o hospedeiro e o cliente estão sincronizados."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_NAT_TRAVERSAL,
      "Ao hospedar uma partida, tente receber conexões da Internet pública usando UPnP ou tecnologias similares para escapar das redes locais."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_STDIN_CMD_ENABLE,
      "Habilitar interface de comando stdin."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_MOUSE_ENABLE,
      "Habilitar controle por Mouse dentro do menu."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_POINTER_ENABLE,
      "Habilitar controle por toque dentro do menu."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_THUMBNAILS,
      "Tipo de miniatura a ser exibida."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_LEFT_THUMBNAILS,
      "Tipo de miniatura para exibir à esquerda."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_XMB_VERTICAL_THUMBNAILS,
      "Exibe a miniatura esquerda sob a direita, no lado direito da tela.")
MSG_HASH(
      MENU_ENUM_SUBLABEL_TIMEDATE_ENABLE,
      "Exibir data e/ou hora atuais dentro do menu."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_BATTERY_LEVEL_ENABLE,
      "Exibir o nível de bateria atual dentro do menu."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NAVIGATION_WRAPAROUND,
      "Voltar ao início ou final se o limite da lista for alcançado horizontalmente ou verticalmente."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_ENABLE_HOST,
      "Habilita o Netplay no modo hospedeiro (servidor)."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_NETPLAY_ENABLE_CLIENT,
      "Habilita o Netplay no modo cliente.")
MSG_HASH(MENU_ENUM_SUBLABEL_NETPLAY_DISCONNECT,
      "Desconecta de uma conexão de Netplay ativa.")
MSG_HASH(MENU_ENUM_SUBLABEL_SCAN_DIRECTORY,
      "Analisa um diretório por arquivos compatíveis e os adiciona à coleção.")
MSG_HASH(MENU_ENUM_SUBLABEL_SCAN_FILE,
      "Analisa um arquivo compatível e o adiciona à coleção.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_SWAP_INTERVAL,
      "Usa um intervalo de troca personalizado para V-Sync. Defina para reduzir efetivamente a taxa de atualização do monitor pela metade."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_SORT_SAVEFILES_ENABLE,
      "Ordenar os Jogos-Salvos em pastas com o nome do núcleo utilizado."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_SORT_SAVESTATES_ENABLE,
      "Ordenar os Estados de Jogo em pastas com o nome do núcleo utilizado."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_NETPLAY_REQUEST_DEVICE_I,
      "Solicitar jogar com o dispositivo de entrada dado.")
MSG_HASH(MENU_ENUM_SUBLABEL_CORE_UPDATER_BUILDBOT_URL,
      "URL para o diretório de atualização de núcleos no buildbot do Libreto.")
MSG_HASH(MENU_ENUM_SUBLABEL_BUILDBOT_ASSETS_URL,
      "URL para o diretório de atualizações de recursos no buildbot do Libretro.")
MSG_HASH(MENU_ENUM_SUBLABEL_CORE_UPDATER_AUTO_EXTRACT_ARCHIVE,
      "Após o download, extrair automaticamente os arquivos contidos nos arquivos comprimidos baixados."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_NETPLAY_REFRESH_ROOMS,
      "Analisar por novas salas.")
MSG_HASH(MENU_ENUM_SUBLABEL_DELETE_ENTRY,
      "Remover esta entrada da coleção.")
MSG_HASH(MENU_ENUM_SUBLABEL_INFORMATION,
      "Visualizar mais informações sobre o conteúdo.")
MSG_HASH(MENU_ENUM_SUBLABEL_ADD_TO_FAVORITES,
      "Adicionar o item aos seus favoritos.")
MSG_HASH(MENU_ENUM_SUBLABEL_ADD_TO_FAVORITES_PLAYLIST,
      "Adicionar o item aos seus favoritos.")
MSG_HASH(MENU_ENUM_SUBLABEL_RUN,
      "Iniciar o conteúdo.")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_FILE_BROWSER_SETTINGS,
      "Ajustar as definições do navegador de arquivos.")
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUTO_REMAPS_ENABLE,
      "Habilitar por padrão controles personalizados na inicialização."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUTO_OVERRIDES_ENABLE,
      "Habilitar por padrão configuração personalizada na inicialização."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_GAME_SPECIFIC_OPTIONS,
      "Habilitar por padrão opções de núcleo personalizadas na inicialização.")
MSG_HASH(MENU_ENUM_SUBLABEL_CORE_ENABLE,
      "Exibir o nome do núcleo atual dentro do menu.")
MSG_HASH(MENU_ENUM_SUBLABEL_DATABASE_MANAGER,
      "Visualizar bases de dados.")
MSG_HASH(MENU_ENUM_SUBLABEL_CURSOR_MANAGER,
      "Visualizar pesquisas anteriores.")
MSG_HASH(MENU_ENUM_SUBLABEL_TAKE_SCREENSHOT,
      "Captura uma imagem da tela.")
MSG_HASH(
      MENU_ENUM_SUBLABEL_CLOSE_CONTENT,
      "Fecha o conteúdo atual. Alterações não salvas serão perdidas."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_LOAD_STATE,
      "Carregar um Estado de Jogo do compartimento selecionado atualmente.")
MSG_HASH(MENU_ENUM_SUBLABEL_SAVE_STATE,
      "Salvar um Estado de Jogo no compartimento selecionado atualmente.")
MSG_HASH(MENU_ENUM_SUBLABEL_RESUME,
      "Retomar a execução do conteúdo atual e sair do Menu Rápido.")
MSG_HASH(MENU_ENUM_SUBLABEL_RESUME_CONTENT,
      "Retomar a execução do conteúdo atual e sair do Menu Rápido.")
MSG_HASH(MENU_ENUM_SUBLABEL_STATE_SLOT,
      "Altera o compartimento do Estado de Jogo selecionado atualmente.")
MSG_HASH(MENU_ENUM_SUBLABEL_UNDO_LOAD_STATE,
      "Se um Estado de Jogo for carregado, o conteúdo voltará ao estado anterior ao carregamento.")
MSG_HASH(MENU_ENUM_SUBLABEL_UNDO_SAVE_STATE,
      "Se o Estado de Jogo foi sobrescrito, ele voltará ao Estado de Jogo salvo anteriormente.")
MSG_HASH(
      MENU_ENUM_SUBLABEL_ACCOUNTS_RETRO_ACHIEVEMENTS,
      "Serviço Retro Achievements. Para mais informações, visite http://retroachievements.org (em inglês)"
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_ACCOUNTS_LIST,
      "Gerenciar contas configuradas atualmente."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_INPUT_META_REWIND,
      "Gerenciar as configurações de Rebobinagem.")
MSG_HASH(MENU_ENUM_SUBLABEL_RESTART_CONTENT,
      "Reinicia o conteúdo do começo.")
MSG_HASH(MENU_ENUM_SUBLABEL_SAVE_CURRENT_CONFIG_OVERRIDE_CORE,
      "Salva um arquivo de redefinição de configuração que será aplicado a todo o conteúdo carregado por este núcleo. Terá prioridade sobre a configuração principal.")
MSG_HASH(MENU_ENUM_SUBLABEL_SAVE_CURRENT_CONFIG_OVERRIDE_GAME,
      "Salva um arquivo de redefinição de configuração que será aplicado apenas ao conteúdo atual. Terá prioridade sobre a configuração principal.")
MSG_HASH(MENU_ENUM_SUBLABEL_CORE_CHEAT_OPTIONS,
      "Configurar códigos de Trapaça.")
MSG_HASH(MENU_ENUM_SUBLABEL_SHADER_OPTIONS,
      "Configurar Shader para realçar a aparência da imagem.")
MSG_HASH(MENU_ENUM_SUBLABEL_CORE_INPUT_REMAPPING_OPTIONS,
      "Alterar os controles para o conteúdo que está sendo executado.")
MSG_HASH(MENU_ENUM_SUBLABEL_CORE_OPTIONS,
      "Alterar as opções para o conteúdo que está sendo executado.")
MSG_HASH(MENU_ENUM_SUBLABEL_SHOW_ADVANCED_SETTINGS,
      "Exibir as configurações avançadas para usuários experientes (oculto por padrão).")
MSG_HASH(MENU_ENUM_SUBLABEL_THREADED_DATA_RUNLOOP_ENABLE,
      "Executar tarefas em linhas de processamento paralelas.")
MSG_HASH(MENU_ENUM_SUBLABEL_PLAYLIST_ENTRY_REMOVE,
      "Permitir que o usuário possa remover itens das coleções.")
MSG_HASH(MENU_ENUM_SUBLABEL_SYSTEM_DIRECTORY,
      "Define o diretório de sistema. Os núcleos podem consultar este diretório para carregar arquivos de BIOS, configurações específicas do sistema, etc.")
MSG_HASH(MENU_ENUM_SUBLABEL_RGUI_BROWSER_DIRECTORY,
      "Define o diretório inicial do navegador de arquivos.")
MSG_HASH(
      MENU_ENUM_SUBLABEL_CONTENT_DIR,
      "Usualmente definido por desenvolvedores que agrupam aplicativos Libretro/RetroArch para apontar para os recursos."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_DYNAMIC_WALLPAPERS_DIRECTORY,
      "Diretório para armazenar planos de fundo dinamicamente carregados pelo menu dependendo do contexto.")
MSG_HASH(MENU_ENUM_SUBLABEL_THUMBNAILS_DIRECTORY,
      "Miniaturas auxiliares (arte da embalagem/imagens diversas e etc.) são armazenadas aqui."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_RGUI_CONFIG_DIRECTORY,
      "Define o diretório inicial para o navegador de configurações do menu.")
MSG_HASH(MENU_ENUM_SUBLABEL_NETPLAY_INPUT_LATENCY_FRAMES_MIN,
      "O número de quadros de latência de entrada para o Netplay utilizar para mascarar a latência da rede. Reduz a oscilação e torna o Netplay menos intensivo para a CPU, ao custo de atraso perceptível na entrada.")
MSG_HASH(MENU_ENUM_SUBLABEL_NETPLAY_INPUT_LATENCY_FRAMES_RANGE,
      "O intervalo de quadros de latência de entrada que pode ser utilizado para mascarar a latência da rede. Reduz a oscilação e torna o Netplay menos intensivo para a CPU, ao custo de atraso imprevisível na entrada.")
MSG_HASH(MENU_ENUM_SUBLABEL_DISK_CYCLE_TRAY_STATUS,
      "Alterna o disco atual. Se o disco estiver inserido, o mesmo será ejetado. Se o disco não estiver inserido, o mesmo será inserido.")
MSG_HASH(MENU_ENUM_SUBLABEL_DISK_INDEX,
      "Mudar o índice do disco.")
MSG_HASH(MENU_ENUM_SUBLABEL_DISK_OPTIONS,
      "Gerenciamento de imagem de disco.")
MSG_HASH(MENU_ENUM_SUBLABEL_DISK_IMAGE_APPEND,
      "Selecione uma imagem de disco para inserir.")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_ENUM_THROTTLE_FRAMERATE,
      "Certifica-se de que a taxa de quadros é controlada enquanto estiver dentro do menu.")
MSG_HASH(MENU_ENUM_SUBLABEL_XMB_LAYOUT,
      "Selecione um layout diferente para a interface XMB.")
MSG_HASH(MENU_ENUM_SUBLABEL_XMB_THEME,
      "Selecionar um tema diferente para os ícones. As alterações terão efeito após reiniciar o programa.")
MSG_HASH(MENU_ENUM_SUBLABEL_XMB_SHADOWS_ENABLE,
      "Habilitar as sombras para todos os ícones. Isto terá um pequeno impacto no desempenho.")
MSG_HASH(MENU_ENUM_SUBLABEL_MATERIALUI_MENU_COLOR_THEME,
      "Selecionar um tema de gradiente de cor de plano de fundo diferente.")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_WALLPAPER_OPACITY,
      "Modificar a opacidade do plano de fundo.")
MSG_HASH(MENU_ENUM_SUBLABEL_XMB_MENU_COLOR_THEME,
      "Selecionar um tema de gradiente de cor de plano de fundo diferente.")
MSG_HASH(MENU_ENUM_SUBLABEL_XMB_RIBBON_ENABLE,
      "Selecionar um efeito de plano de fundo animado. Pode exigir mais processamento da GPU dependendo do efeito. Se o desempenho for insatisfatório, desligue este efeito ou reverta para um efeito mais simples.")
MSG_HASH(MENU_ENUM_SUBLABEL_XMB_FONT,
      "Selecionar uma fonte principal diferente para ser usada pelo menu.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_FAVORITES,
      "Exibir a aba de favoritos dentro do menu principal.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_IMAGES,
      "Exibir a aba de imagem dentro do menu principal.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_MUSIC,
      "Exibir a aba de música dentro do menu principal.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_VIDEO,
      "Exibir a aba de vídeo dentro do menu principal.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_NETPLAY,
      "Exibir a aba de Netplay dentro do menu principal.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_SETTINGS,
      "Mostrar a aba de configurações dentro do menu principal.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_HISTORY,
      "Mostrar a aba de histórico recente dentro do menu principal.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_ADD,
      "Mostrar a aba de importação de conteúdo dentro do menu principal.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_PLAYLISTS,
      "Exibir abas da lista de reprodução dentro do menu principal.")
MSG_HASH(MENU_ENUM_SUBLABEL_RGUI_SHOW_START_SCREEN,
      "Exibir a tela inicial no menu. É automaticamente definido como falso após o programa iniciar pela primeira vez.")
MSG_HASH(MENU_ENUM_SUBLABEL_MATERIALUI_MENU_HEADER_OPACITY,
      "Modificar a opacidade do gráfico do cabeçalho.")
MSG_HASH(MENU_ENUM_SUBLABEL_MATERIALUI_MENU_FOOTER_OPACITY,
      "Modificar a opacidade do gráfico do rodapé.")
MSG_HASH(MENU_ENUM_SUBLABEL_DPI_OVERRIDE_ENABLE,
      "O menu normalmente se dimensiona dinamicamente. Se você desejar definir uma escala de tamanho específica em vez disto, habilite esta função.")
MSG_HASH(MENU_ENUM_SUBLABEL_DPI_OVERRIDE_VALUE,
      "Definir o tamanho do dimensionamento personalizado aqui. OBS: Você deve habilitar a função 'Redefinição de DPI' para que este dimensionamento tenha efeito.")
MSG_HASH(MENU_ENUM_SUBLABEL_CORE_ASSETS_DIRECTORY,
      "Salvar todos os arquivos baixados neste diretório.")
MSG_HASH(MENU_ENUM_SUBLABEL_INPUT_REMAPPING_DIRECTORY,
      "Salvar todos os controles remapeados neste diretório.")
MSG_HASH(MENU_ENUM_SUBLABEL_LIBRETRO_DIR_PATH,
      "Diretório onde o programa busca por conteúdo/núcleos.")
MSG_HASH(MENU_ENUM_SUBLABEL_LIBRETRO_INFO_PATH,
      "Os arquivos de informação do aplicativo/núcleo são armazenados aqui.")
MSG_HASH(MENU_ENUM_SUBLABEL_JOYPAD_AUTOCONFIG_DIR,
      "Se um Joypad estiver conectado, o mesmo será autoconfigurado se um arquivo de configuração correspondente estiver presente dento deste diretório.")
MSG_HASH(MENU_ENUM_SUBLABEL_PLAYLIST_DIRECTORY,
      "Salvar todas as coleções neste diretório.")
MSG_HASH(
      MENU_ENUM_SUBLABEL_CACHE_DIRECTORY,
      "Se for definido um diretório, o conteúdo que é temporariamente extraído (ex: dos arquivos) sera extraído para este diretório."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_CURSOR_DIRECTORY,
      "As consultas salvas são armazenadas neste diretório.")
MSG_HASH(
      MENU_ENUM_SUBLABEL_CONTENT_DATABASE_DIRECTORY,
      "As bases de dados são armazenadas neste diretório."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_ASSETS_DIRECTORY,
      "Esta localização é consultada por padrão quando a interface do menu tenta procurar por recursos carregáveis, etc."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_SAVEFILE_DIRECTORY,
      "Salvar todos os Jogos-Salvos neste diretório. Se não for definido, tentaremos salvar dentro do diretório de trabalho do arquivo.")
MSG_HASH(MENU_ENUM_SUBLABEL_SAVESTATE_DIRECTORY,
      "Salvar todos os Estados de Jogo neste diretório. Se não for definido, tentaremos salvar dentro do diretório de trabalho do arquivo.")
MSG_HASH(MENU_ENUM_SUBLABEL_SCREENSHOT_DIRECTORY,
      "Diretório para armazenar as capturas de tela.")
MSG_HASH(MENU_ENUM_SUBLABEL_OVERLAY_DIRECTORY,
      "Define um diretório onde as Transparências são mantidas para fácil acesso.")
MSG_HASH(
      MENU_ENUM_SUBLABEL_CHEAT_DATABASE_PATH,
      "Os arquivos de Trapaça são mantidos aqui."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUDIO_FILTER_DIR,
      "Diretório onde os arquivos de filtro DSP de áudio são mantidos."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_FILTER_DIR,
      "Diretório onde os arquivos de filtro de vídeo processado por CPU são mantidos."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_SHADER_DIR,
      "Define um diretório onde os arquivos de Shader de vídeo processado por GPU são mantidos para fácil acesso.")
MSG_HASH(MENU_ENUM_SUBLABEL_RECORDING_OUTPUT_DIRECTORY,
      "As gravações serão armazenadas neste diretório.")
MSG_HASH(MENU_ENUM_SUBLABEL_RECORDING_CONFIG_DIRECTORY,
      "As configurações de gravação serão mantidas aqui.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_FONT_PATH,
      "Selecionar uma fonte diferente para as notificações na tela.")
MSG_HASH(MENU_ENUM_SUBLABEL_SHADER_APPLY_CHANGES,
      "As alterações das configurações de Shader terão efeito imediato. Use isto se você alterou a quantidade de estágios de Shader, filtros, escala FBO, etc.")
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_SHADER_NUM_PASSES,
      "Aumentar ou diminuir a quantidade de estágios do pipeline de Shader. Você pode adicionar um Shader separado para cada estágio do pipeline e configurar sua escala e filtro."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_SHADER_PRESET,
      "Carregar uma predefinição de Shader. O pipeline de Shader será definido automaticamente.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_SHADER_PRESET_SAVE_AS,
      "Salvar as definições de Shader atuais como uma nova predefinição de Shader.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_SHADER_PRESET_SAVE_CORE,
      "Salvar as definições de Shader atuais como a definição padrão para esta aplicação/núcleo.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_SHADER_PRESET_SAVE_PARENT,
      "Salve as configurações atuais do shader como as configurações padrão para todos os arquivos no diretório de conteúdo atual.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_SHADER_PRESET_SAVE_GAME,
      "Salvar as definições de Shader atuais como a definição padrão para o conteúdo.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_SHADER_PARAMETERS,
      "Modifica diretamente o Shader atual. As alterações não serão salvas no arquivo de predefinição.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_SHADER_PRESET_PARAMETERS,
      "Modifica a predefinição de Shader atualmente utilizada no menu.")
MSG_HASH(
      MENU_ENUM_SUBLABEL_CHEAT_NUM_PASSES,
      "Aumentar ou diminuir a quantidade de Trapaças."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_CHEAT_APPLY_CHANGES,
      "As alterações de Trapaça terão efeito imediato.")
MSG_HASH(
      MENU_ENUM_SUBLABEL_CHEAT_FILE_LOAD,
      "Carregar um arquivo de Trapaça."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_CHEAT_FILE_SAVE_AS,
      "Salvar as Trapaças atuais como um arquivo de Jogo-Salvo."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SETTINGS,
      "Acessar rapidamente todas as configurações relevantes ao jogo.")
MSG_HASH(MENU_ENUM_SUBLABEL_CORE_INFORMATION,
      "Visualizar informações sobre a aplicação/núcleo.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_ASPECT_RATIO,
      "Valor em ponto flutuante da proporção de tela (largura / altura), utilizado se Proporção de Tela estiver definido como 'Configuração'.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_VIEWPORT_CUSTOM_HEIGHT,
      "Personalizar a altura da janela de exibição que é usada se a Proporção de Tela estiver definida como 'Personalizada'.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_VIEWPORT_CUSTOM_WIDTH,
      "Personalizar a largura da janela de exibição que é usada se a Proporção de Tela estiver definida como 'Personalizada'.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_VIEWPORT_CUSTOM_X,
      "Deslocamento personalizado no eixo-X da janela de exibição. Será ignorado se a 'Escala em Inteiros' estiver habilitada. Neste caso ela será centralizada automaticamente.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_VIEWPORT_CUSTOM_Y,
      "Deslocamento personalizado no eixo-Y da janela de exibição. Será ignorado se a 'Escala em Inteiros' estiver habilitada. Neste caso ela será centralizada automaticamente.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_USE_MITM_SERVER,
      "Utilizar Servidor MITM")
MSG_HASH(MENU_ENUM_SUBLABEL_NETPLAY_USE_MITM_SERVER,
      "Encaminhar conexões do Netplay através de um servidor 'homem no meio' (MITM). Útil se o hospedeiro estiver atrás de um firewall ou tiver problemas de NAT/UPnP.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_MITM_SERVER,
      "Localização do Servidor de Retransmissão")
MSG_HASH(MENU_ENUM_SUBLABEL_NETPLAY_MITM_SERVER,
      "Escolha um servidor de retransmissão específico para usar. Locais geograficamente mais próximos tendem a ter menor latência.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ADD_TO_MIXER,
      "Adicionar ao mixer")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ADD_TO_MIXER_AND_PLAY,
      "Add to mixer and play")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ADD_TO_MIXER_AND_COLLECTION,
      "Adicionar ao mixer")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ADD_TO_MIXER_AND_COLLECTION_AND_PLAY,
      "Add to mixer and play")
MSG_HASH(MENU_ENUM_LABEL_VALUE_FILTER_BY_CURRENT_CORE,
      "Filtrar por núcleo atual")
MSG_HASH(
      MSG_AUDIO_MIXER_VOLUME,
      "Volume global do mixer de áudio"
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUDIO_MIXER_VOLUME,
      "Volume global do mixer de áudio (em dB). 0dB é o volume normal, e nenhum ganho será aplicado."
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_MIXER_VOLUME,
      "Nível de Volume do Mixer de Áudio (dB)"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_MIXER_MUTE,
      "Mixer de Áudio Mudo"
      )
MSG_HASH(MENU_ENUM_SUBLABEL_AUDIO_MIXER_MUTE,
      "Mixer de áudio mudo/não-mudo.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_SHOW_ONLINE_UPDATER,
      "Exibir Atualizador Online")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_SHOW_ONLINE_UPDATER,
      "Exibir/ocultar a opção 'Atualizador Online'.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_VIEWS_SETTINGS,
      "Visualizações")
MSG_HASH(
      MENU_ENUM_SUBLABEL_MENU_VIEWS_SETTINGS,
      "Exibir elementos na tela de menu."
      )
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_SHOW_CORE_UPDATER,
      "Exibir Atualizador de Núcleos")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_SHOW_CORE_UPDATER,
      "Exibir a opção de atualizar núcleos (e arquivos de informação de núcleo).")
MSG_HASH(MSG_PREPARING_FOR_CONTENT_SCAN,
      "Preparando a busca de conteúdo...")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_DELETE,
      "Remover núcleo")
MSG_HASH(MENU_ENUM_SUBLABEL_CORE_DELETE,
      "Remover este núcleo do disco.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_FRAMEBUFFER_OPACITY,
      "Opacidade do Framebuffer")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_FRAMEBUFFER_OPACITY,
      "Modificar a opacidade do framebuffer.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_GOTO_FAVORITES,
      "Favoritos")
MSG_HASH(MENU_ENUM_SUBLABEL_GOTO_FAVORITES,
      "Conteúdo adicionado aos 'Favoritos' vai aparecer aqui.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_GOTO_MUSIC,
      "Músicas")
MSG_HASH(MENU_ENUM_SUBLABEL_GOTO_MUSIC,
      "Músicas que foram reproduzidas aparecem aqui.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_GOTO_IMAGES,
      "Imagens")
MSG_HASH(MENU_ENUM_SUBLABEL_GOTO_IMAGES,
      "Imagens que foram exibidas aparecem aqui.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_GOTO_VIDEO,
      "Vídeos")
MSG_HASH(MENU_ENUM_SUBLABEL_GOTO_VIDEO,
      "Vídeos que foram reproduzidos aparecem aqui.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MATERIALUI_ICONS_ENABLE,
      "Ícones do Menu")
MSG_HASH(MENU_ENUM_SUBLABEL_MATERIALUI_ICONS_ENABLE,
      "Habilitar/desabilitar os ícones exibidos do lado esquerdo dos itens de menu.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MAIN_MENU_ENABLE_SETTINGS,
      "Habilitar aba de configurações")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_SETTINGS_PASSWORD,
      "Definir senha para habilitar aba de configurações")
MSG_HASH(MSG_INPUT_ENABLE_SETTINGS_PASSWORD,
      "Digite a senha")
MSG_HASH(MSG_INPUT_ENABLE_SETTINGS_PASSWORD_OK,
      "Senha correta.")
MSG_HASH(MSG_INPUT_ENABLE_SETTINGS_PASSWORD_NOK,
      "Senha incorreta.")
MSG_HASH(MENU_ENUM_SUBLABEL_XMB_MAIN_MENU_ENABLE_SETTINGS,
      "Habilita a aba de configurações. É necessário reiniciar para que a aba apareça.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_SETTINGS_PASSWORD,
      "O fornecimento de uma senha ao ocultar a aba de configurações permite restaurar mais tarde a partir do menu, indo para a aba Menu Principal, selecionando Habilitar aba configurações e inserindo a senha.")
MSG_HASH(MENU_ENUM_SUBLABEL_PLAYLIST_ENTRY_RENAME,
      "Permita que o usuário renomeie os itens nas coleções.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PLAYLIST_ENTRY_RENAME,
      "Permitir renomear itens"      )
MSG_HASH(MENU_ENUM_SUBLABEL_RENAME_ENTRY,
      "Renomear o título do item.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RENAME_ENTRY,
      "Renomear")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_SHOW_LOAD_CORE,
      "Exibir 'Carregar Núcleo'")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_SHOW_LOAD_CORE,
      "Exibir/ocultar a opção 'Carregar Núcleo'.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_SHOW_LOAD_CONTENT,
      "Exibir Carregar Conteúdo")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_SHOW_LOAD_CONTENT,
      "Exibir/ocultar a opção 'Carregar Conteúdo'.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_SHOW_INFORMATION,
      "Exibir Informação")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_SHOW_INFORMATION,
      "Exibir/ocultar a opção 'Informação'.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_SHOW_CONFIGURATIONS,
      "Exibir Configurações")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_SHOW_CONFIGURATIONS,
      "Exibir/ocultar a opção 'Configurações'.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_SHOW_HELP,
      "Exibir Ajuda")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_SHOW_HELP,
      "Exibir/ocultar a opção 'Ajuda'.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_SHOW_QUIT_RETROARCH,
      "Exibir Sair do RetroArch")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_SHOW_QUIT_RETROARCH,
      "Exibir/ocultar a opção 'Sair do RetroArch'.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_SHOW_REBOOT,
      "Exibir Reiniciar")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_SHOW_REBOOT,
      "Exibir/ocultar a opção 'Reiniciar'.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_VIEWS_SETTINGS,
      "Menu Rápido")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_VIEWS_SETTINGS,
      "Exibir ou ocultar elementos na tela de Menu Rápido.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_TAKE_SCREENSHOT,
      "Exibir 'Captura de Tela'")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_TAKE_SCREENSHOT,
      "Exibir/ocultar a opção 'Captura de Tela'.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_SAVE_LOAD_STATE,
      "Exibir Salvar/Carregar Estado")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_SAVE_LOAD_STATE,
      "Exibir/ocultar as opções para salvar/carregar estados.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_UNDO_SAVE_LOAD_STATE,
      "Exibir Desfazer Salvar/Carregar Estado")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_UNDO_SAVE_LOAD_STATE,
      "Exibir/ocultar as opções para abolir o salvar/carregar estado.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_ADD_TO_FAVORITES,
      "Exibir Adicionar aos Favoritos")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_ADD_TO_FAVORITES,
      "Exibir/ocultar a opção 'Adicionar aos Favoritos'.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_OPTIONS,
      "Exibir Opções")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_OPTIONS,
      "Exibir/ocultar a opção 'Opções'.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_CONTROLS,
      "Exibir Controles")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_CONTROLS,
      "Exibir/ocultar a opção 'Controles'.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_CHEATS,
      "Exibir Trapaças")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_CHEATS,
      "Exibir/ocultar a opção 'Trapaças'.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_SHADERS,
      "Exibir 'Shaders'")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_SHADERS,
      "Exibir/ocultar a opção 'Shaders'.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_SAVE_CORE_OVERRIDES,
      "Exibir Salvar Redefinição de Núcleo")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_SAVE_CORE_OVERRIDES,
      "Exibir/ocultar a opção 'Salvar Redefinição de Núcleo'.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_SAVE_GAME_OVERRIDES,
      "Exibir Salvar Redefinição de Jogo")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_SAVE_GAME_OVERRIDES,
      "Exibir/ocultar a opção 'Salvar Redefinição de Jogo'.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_INFORMATION,
      "Exibir Informação")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_INFORMATION,
      "Exibir/ocultar a opção 'Informação'.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_MESSAGE_BGCOLOR_ENABLE,
      "Ativar Notificação de Fundo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_MESSAGE_BGCOLOR_RED,
      "Notificação de Fundo em Cor Vermelha")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_MESSAGE_BGCOLOR_GREEN,
      "Notificação de Fundo em Cor Verde")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_MESSAGE_BGCOLOR_BLUE,
      "Notificação de Fundo em Cor Azul")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_MESSAGE_BGCOLOR_OPACITY,
      "Opacidade da Notificação de Fundo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_DISABLE_KIOSK_MODE,
      "Desabilitar o Modo Quiosque")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_DISABLE_KIOSK_MODE,
      "Desabilita o Modo Quiosque. É necessária uma reinicialização para que a mudança tenha total efeito.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_ENABLE_KIOSK_MODE,
      "Habilitar o Modo Quiosque")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_ENABLE_KIOSK_MODE,
      "Protege a configuração escondendo todas as configurações relacionadas à configuração.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_KIOSK_MODE_PASSWORD,
      "Definir senha para desabilitar o Modo Quiosque")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_KIOSK_MODE_PASSWORD,
      "Fornecer uma senha ao habilitar o Modo Quiosque tornando possível desabilitar mais tarde a partir do menu, indo para o Menu Principal, selecionando Desabilitar o Modo Quiosque e inserindo a senha.")
MSG_HASH(MSG_INPUT_KIOSK_MODE_PASSWORD,
      "Digite a Senha")
MSG_HASH(MSG_INPUT_KIOSK_MODE_PASSWORD_OK,
      "Senha correta.")
MSG_HASH(MSG_INPUT_KIOSK_MODE_PASSWORD_NOK,
      "Senha incorreta.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_MESSAGE_COLOR_RED,
      "Notificação em Cor Vermelha")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_MESSAGE_COLOR_GREEN,
      "Notificação em Cor Verde")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_MESSAGE_COLOR_BLUE,
      "Notificação em Cor Azul")
MSG_HASH(MENU_ENUM_LABEL_VALUE_FRAMECOUNT_SHOW,
      "Exibir contagem de quadros na tela FPS")
MSG_HASH(MSG_CONFIG_OVERRIDE_LOADED,
      "Substituição de configuração carregada.")
MSG_HASH(MSG_GAME_REMAP_FILE_LOADED,
      "Arquivo de remapeamento do jogo carregado.")
MSG_HASH(MSG_CORE_REMAP_FILE_LOADED,
      "Arquivo de remapeamento principal carregado.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_AUTOMATICALLY_ADD_CONTENT_TO_PLAYLIST,
      "Adicione automaticamente conteúdo à lista de reprodução")
MSG_HASH(MENU_ENUM_SUBLABEL_AUTOMATICALLY_ADD_CONTENT_TO_PLAYLIST,
      "Verifica automaticamente o conteúdo carregado para que eles apareçam dentro das listas de reprodução.")
MSG_HASH(MSG_SCANNING_OF_FILE_FINISHED,
      "Verificação do arquivo terminado")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_WINDOW_OPACITY,
      "Opacidade da Janela")
MSG_HASH(MENU_ENUM_LABEL_VALUE_AUDIO_RESAMPLER_QUALITY,
      "Qualidade da Reamostragem do Áudio")
MSG_HASH(MENU_ENUM_SUBLABEL_AUDIO_RESAMPLER_QUALITY,
      "Abaixe esse valor para favorecer o desempenho/baixa latência em relação à qualidade de áudio, aumente se desejar melhor qualidade de áudio à custa do desempenho/baixa latência.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHADER_WATCH_FOR_CHANGES,
      "Ver arquivos de shader para mudanças")
MSG_HASH(MENU_ENUM_SUBLABEL_SHADER_WATCH_FOR_CHANGES,
      "Aplicar automaticamente as alterações feitas nos arquivos de shader no disco.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_WINDOW_SHOW_DECORATIONS,
      "Exibir Decorações da Janela")
MSG_HASH(MENU_ENUM_LABEL_VALUE_STATISTICS_SHOW,
      "Exibir estatísticas")
MSG_HASH(MENU_ENUM_SUBLABEL_STATISTICS_SHOW,
      "Mostrar estatísticas técnicas na tela.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_RGUI_BORDER_FILLER_ENABLE,
      "Ativar preenchimento de borda")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_RGUI_BORDER_FILLER_THICKNESS_ENABLE,
      "Ativar espessura de preenchimento de borda")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_RGUI_BACKGROUND_FILLER_THICKNESS_ENABLE,
      "Ativar espessura de preenchimento do plano de fundo")
MSG_HASH(MENU_ENUM_SUBLABEL_CRT_SWITCH_RESOLUTION,
      "Para monitores CRT de 15 kHz apenas. Tenta usar a resolução exata do núcleo/jogo e a taxa de atualização.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CRT_SWITCH_RESOLUTION,
      "Trocar para Resolução CRT")
MSG_HASH(MENU_ENUM_SUBLABEL_CRT_SWITCH_RESOLUTION_SUPER,
      "Quando Trocar para Resolução CRT está ativada, força a resolução horizontal ultrawide  para minimizar a alternância de modo.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CRT_SWITCH_RESOLUTION_SUPER,
      "Super Resolução CRT")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_REWIND,
      "Exibir Configurações de Rebobinagem")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_REWIND,
      "Exibir/ocultar as opções de Rebobinagem.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_LATENCY,
      "Exibir/ocultar as opções de Latência.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_LATENCY,
      "Exibir Configurações de Latência")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_OVERLAYS,
      "Exibir/ocultar as opções de Sobreposição.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_OVERLAYS,
      "Exibir Configurações de Sobreposição")
MSG_HASH(MENU_ENUM_LABEL_VALUE_AUDIO_ENABLE_MENU,
      "Ativar áudio de menu")
MSG_HASH(MENU_ENUM_SUBLABEL_AUDIO_ENABLE_MENU,
      "Ativar ou desativar o som do menu.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_AUDIO_MIXER_SETTINGS,
      "Configurações do Mixer")
MSG_HASH(MENU_ENUM_SUBLABEL_AUDIO_MIXER_SETTINGS,
      "Visualizar e/ou modificar as configurações do mixer de áudio.") 
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_INFO,
      "Informação")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_MENU_FILE,
      "&Arquivo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_MENU_FILE_LOAD_CORE,
      "&Carregar Núcleo...")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_MENU_FILE_UNLOAD_CORE,
      "&Descarregar Núcleo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_MENU_FILE_EXIT,
      "Sai&r")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_MENU_EDIT,
      "&Editar")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_MENU_EDIT_SEARCH,
      "&Pesquisar")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_MENU_VIEW,
      "&Visualizar")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_MENU_VIEW_CLOSED_DOCKS,
      "Docas Fechadas")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_MENU_VIEW_OPTIONS,
      "&Opções...")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_MENU_VIEW_OPTIONS_SAVE_DOCK_POSITIONS,
      "Lembrar posições da doca:")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_MENU_VIEW_OPTIONS_SAVE_GEOMETRY,
      "Lembrar geometria da janela:")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_MENU_VIEW_OPTIONS_SAVE_LAST_TAB,
      "Lembrar a última aba do navegador de conteúdo:")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_MENU_VIEW_OPTIONS_THEME,
      "Tema")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_MENU_VIEW_OPTIONS_THEME_SYSTEM_DEFAULT,
      "<Padrão do Sistema>")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_MENU_VIEW_OPTIONS_THEME_DARK,
      "Escuro")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_MENU_VIEW_OPTIONS_THEME_CUSTOM,
      "Personalizado...")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_MENU_VIEW_OPTIONS_TITLE,
      "Opções")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_LOAD_CUSTOM_CORE,
      "Carregar Núcleo Personalizado...")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_LOAD_CORE,
      "Carregar Núcleo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_LOADING_CORE,
      "Carregando Núcleo...")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_NAME,
      "Nome")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_CORE_VERSION,
      "Versão")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_TAB_PLAYLISTS,
      "Listas de Reprodução")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_TAB_FILE_BROWSER,
      "Navegador de Arquivos")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_TAB_FILE_BROWSER_TOP,
      "Topo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_TAB_FILE_BROWSER_UP,
      "Subir")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_MENU_DOCK_CONTENT_BROWSER,
      "Navegador de Conteúdo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_THUMBNAIL_BOXART,
      "Arte da Capa")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_THUMBNAIL_SCREENSHOT,
      "Captura de Tela")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_THUMBNAIL_TITLE_SCREEN,
      "Tela de Título")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_ALL_PLAYLISTS,
      "Todas as Listas de Reprodução")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_CORE,
      "Núcleo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_CORE_INFO,
      "Informação do Núcleo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_CORE_SELECTION_ASK,
      "<Me pergunte>")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_INFORMATION,
      "Informação")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_WARNING,
      "Advertência")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_ERROR,
      "Erro")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_RESTART_TO_TAKE_EFFECT,
      "Por favor, reinicie o programa para que as alterações entrem em vigor.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_LOG,
      "Relatório")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_SCAN_FINISHED,
      "Verificação Terminada.<br><br>\n"
      "Para que o conteúdo seja verificado corretamente, você deve em ordem:\n"
      "<ul><li>ter um núcleo compatível já baixado</li>\n"
      "<li>ter os \"Arquivos de Informação de Núcleo\" atualizados via Atualizador Online</li>\n"
      "<li>ter a \"Base de Dados\" atualizada via Atualizador Online</li>\n"
      "<li>reiniciar o RetroArch caso alguma das situações acima tenha sido feita</li></ul>\n"
      "E finalmente, o conteúdo deve corresponder as bases de dados existentes <a href=\"https://docs.libretro.com/guides/roms-playlists-thumbnails/#sources\">aqui</a>. Se ainda não estiver funcionando, considere <a href=\"https://www.github.com/libretro/RetroArch/issues\">enviar um relatório de erro</a>.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_DONT_SHOW_AGAIN,
      "Não mostrar isto novamente")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_STOP,
      "Parar")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_ASSOCIATE_CORE,
      "Associar Núcleo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_HIDDEN_PLAYLISTS,
      "Ocultar Listas de Reprodução")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_HIDE,
      "Ocultar")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_MENU_VIEW_OPTIONS_HIGHLIGHT_COLOR,
      "Cor de Destaque")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_CHOOSE,
      "&Escolher...")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_SELECT_COLOR,
      "Selecionar Cor")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_SELECT_THEME,
      "Selecionar Tema")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_CUSTOM_THEME,
      "Tema Personalizado")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_FILE_PATH_IS_BLANK,
      "O caminho do arquivo está em branco.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_FILE_IS_EMPTY,
      "O arquivo está vazio.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_FILE_READ_OPEN_FAILED,
      "Não foi possível abrir o arquivo para leitura.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_FILE_DOES_NOT_EXIST,
      "O arquivo não existe.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_MENU_VIEW_OPTIONS_SUGGEST_LOADED_CORE_FIRST,
      "Sugerir primeiro núcleo carregado")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_OVERRIDE_OPTIONS,
      "Configuration Override options")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_OVERRIDE_OPTIONS,
      "Options for overriding the global configuration.")
MSG_HASH(MENU_ENUM_SUBLABEL_MIXER_ACTION_PLAY,
      "Will start playback of the audio stream. Once finished, it will remove the current audio stream from memory.")
MSG_HASH(MENU_ENUM_SUBLABEL_MIXER_ACTION_PLAY_LOOPED,
      "Will start playback of the audio stream. Once finished, it will loop and play the track again from the beginning.")
MSG_HASH(MENU_ENUM_SUBLABEL_MIXER_ACTION_PLAY_SEQUENTIAL,
      "Will start playback of the audio stream. Once finished, it will jump to the next audio stream in sequential order and repeat this behavior. Useful as an album playback mode.")
MSG_HASH(MENU_ENUM_SUBLABEL_MIXER_ACTION_STOP,
      "This will stop playback of the audio stream, but not remove it from memory. You can start playing it again by selecting 'Play'.")
MSG_HASH(MENU_ENUM_SUBLABEL_MIXER_ACTION_REMOVE,
      "This will stop playback of the audio stream and remove it entirely from memory.")
MSG_HASH(MENU_ENUM_SUBLABEL_MIXER_ACTION_VOLUME,
      "Adjust the volume of the audio stream.")
MSG_HASH(MENU_ENUM_SUBLABEL_ADD_TO_MIXER,
      "Add this audio track to an available audio stream slot. If no slots are currently available, it will be ignored.")
MSG_HASH(MENU_ENUM_SUBLABEL_ADD_TO_MIXER_AND_PLAY,
      "Add this audio track to an available audio stream slot and play it. If no slots are currently available, it will be ignored.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MIXER_ACTION_PLAY,
      "Play")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MIXER_ACTION_PLAY_LOOPED,
      "Play (Looped)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MIXER_ACTION_PLAY_SEQUENTIAL,
      "Play (Sequential)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MIXER_ACTION_STOP,
      "Stop")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MIXER_ACTION_REMOVE,
      "Remove")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MIXER_ACTION_VOLUME,
      "Volume")
